<?php
/**
 * The template for adding About us Content Settings in Customizer
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
    header( 'Status: 403 Forbidden' );
    header( 'HTTP/1.1 403 Forbidden' );
    exit();
}
    // Bottom Section Content Options
    if ( 4.3 > get_bloginfo( 'version' ) ) {
        $wp_customize->add_panel( 'flat_commerce_bottom_section_options', array(
            'capability'     => 'edit_theme_options',
            'description'    => esc_html__( 'Bottom Section', 'flat-commerce' ),
            'priority'       => 600,
            'title'          => esc_html__( 'Bottom Section Content', 'flat-commerce' ),
        ) );

        $wp_customize->add_section( 'flat_commerce_bottom_section_settings', array(
            'panel'         => 'flat_commerce_bottom_section_options',
            'priority'      => 1,
            'title'         => esc_html__( 'Bottom Section', 'flat-commerce' ),
        ) );
    }
    else {
        $wp_customize->add_section( 'flat_commerce_bottom_section_settings', array(
            'priority'      => 600,
            'title'         => esc_html__( 'Bottom Section', 'flat-commerce' ),
        ) );
    }

    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_enable_option]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['bottom_section_enable_option'],
        'sanitize_callback' => 'flat_commerce_sanitize_select',
    ) );

    $bottom_section_enable_options = flat_commerce_bottom_section_enable_options(); //get options to enable about us section

    $choices = array();

    foreach ( $bottom_section_enable_options as $bottom_section_enable_option ) {
        $choices[ $bottom_section_enable_option['value']] = $bottom_section_enable_option['label'];
    }

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_enable_option]', array(
        'label'             => esc_html__( 'Enable Bottom Section on', 'flat-commerce' ),
        'priority'          => '10',
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_enable_option]',
        'type'              => 'select',
        'choices'           => $choices,
    ) );

    // Bottom section design type.
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_design_option]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['bottom_section_design_option'],
        'sanitize_callback' => 'flat_commerce_sanitize_select',
    ) );

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_design_option]', array(
        'label'             => esc_html__( 'Select Design:', 'flat-commerce' ),
        'priority'          => '15',
        'section'           => 'flat_commerce_bottom_section_settings',
        'type'              => 'radio',
        'choices'           => array( 
            'design-1' => esc_html__( 'Image on Background', 'flat-commerce' ), 
            'design-2' => esc_html__( 'Image on Left', 'flat-commerce' ), 
            ),
    ) );

    // Content type
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_content_type]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['bottom_section_content_type'],
        'sanitize_callback' => 'flat_commerce_sanitize_select',
    ) );

    $bottom_section_content_types = flat_commerce_bottom_section_content_types(); //get options to enable about us section

    $choices = array();

    foreach ( $bottom_section_content_types as $bottom_section_content_type ) {
        $choices[ $bottom_section_content_type['value']] = $bottom_section_content_type['label'];
    }

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_content_type]', array(
        'active_callback'   => 'flat_commerce_is_bottom_section_active',
        'label'             => esc_html__( 'Content Type', 'flat-commerce' ),
        'priority'          => '15',
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_content_type]',
        'type'              => 'select',
        'choices'           => $choices,
    ) );

    // Title
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_title]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['bottom_section_title'],
        'transport'         => 'postMessage',
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    // Abort if selective refresh is not available.
    if ( isset( $wp_customize->selective_refresh ) ) {
        $wp_customize->selective_refresh->add_partial( 'flat_commerce_theme_options[bottom_section_title]', array(
            'selector'            => '#bottom-section .entry-header h2.entry-title',
            'render_callback'     => 'flat_commerce_customize_partial_bottom_section_title',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
        ) );
    }

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_title]', array(
        'active_callback'   => 'flat_commerce_is_custom_content_type_active',
        'label'             => esc_html__( 'Title', 'flat-commerce' ),
        'priority'          => '20',
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_title]',
        'type'              => 'text',
    ) );

    // Sub title
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_sub_title]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['bottom_section_sub_title'],
        'transport'         => 'postMessage',
        'sanitize_callback' => 'esc_textarea',
    ) );

    // Abort if selective refresh is not available.
    if ( isset( $wp_customize->selective_refresh ) ) {
        $wp_customize->selective_refresh->add_partial( 'flat_commerce_theme_options[bottom_section_sub_title]', array(
            'selector'            => '#bottom-section .entry-content p',
            'render_callback'     => 'flat_commerce_customize_partial_bottom_section_sub_title',
            'container_inclusive' => false,
            'fallback_refresh'    => true,
        ) );
    }

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_sub_title]', array(
        'active_callback'   => 'flat_commerce_is_custom_content_type_active',
        'label'             => esc_html__( 'Sub Title', 'flat-commerce' ),
        'priority'          => '30',
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_sub_title]',
        'type'              => 'textarea',
    ) );

    // Page drop down
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_page]', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'esc_textarea',
    ) );

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_page]', array(
        'active_callback'   => 'flat_commerce_is_page_content_type_active',
        'label'             => esc_html__( 'Select Page', 'flat-commerce' ),
        'priority'          => '30',
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_page]',
        'type'              => 'dropdown-pages',
    ) );

    // Enable read more link
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_read_more_link]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['bottom_section_read_more_link'],
        'sanitize_callback' => 'flat_commerce_sanitize_checkbox'
    ) );

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_read_more_link]', array(
        'active_callback'   => 'flat_commerce_is_bottom_section_active',
        'label'             => esc_html__( 'Check to display "Read More" link', 'flat-commerce' ),
        'priority'          => '40',
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_read_more_link]',
        'type'              => 'checkbox',
    ) );

    // Link text
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_read_more_link_text]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['bottom_section_read_more_link_text'],
        'sanitize_callback' => 'sanitize_text_field'
    ) );

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_read_more_link_text]', array(
        'active_callback'   => 'flat_commerce_is_bottom_section_read_more_link_enabled',
        'label'             => esc_html__( 'Link Text', 'flat-commerce' ),
        'priority'          => '50',
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_read_more_link_text]',
        'type'              => 'text',
    ) );

    //Link to url
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_read_more_link_to]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['bottom_section_read_more_link_to'],
        'sanitize_callback' => 'esc_url'
    ) );

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_read_more_link_to]', array(
        'active_callback'   => 'flat_commerce_is_bottom_section_read_more_link_custom_type_enabled',
        'label'             => esc_html__( 'Link To:', 'flat-commerce' ),
        'description'       => esc_html__( 'Enter the URL you want to link to', 'flat-commerce' ),
        'priority'          => '60',
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_read_more_link_to]',
        'type'              => 'url',
    ) );

    // Enable social media
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_social_media]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['bottom_section_social_media'],
        'sanitize_callback' => 'flat_commerce_sanitize_checkbox'
    ) );

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_social_media]', array(
        'active_callback'   => 'flat_commerce_is_bottom_section_active',
        'label'             => esc_html__( 'Check to enable social media icons', 'flat-commerce' ),
        'priority'          => '70',
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_social_media]',
        'type'              => 'checkbox',
    ) );

    // Background image
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_bg_image]', array(
        'capability'        => 'edit_theme_options',
        'sanitize_callback' => 'flat_commerce_sanitize_image'
    ) );

    $wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'flat_commerce_theme_options[bottom_section_bg_image]', array(
        'active_callback'   => 'flat_commerce_is_bottom_section_active',
        'label'             => esc_html__( 'Change section background', 'flat-commerce' ),
        'description'             => esc_html__( 'Recommended size is: 1600x1336.', 'flat-commerce' ),
        'priority'          => '75',
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_bg_image]',
    ) ) );

    // Social media number
    $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_social_media_number]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['bottom_section_social_media_number'],
        'sanitize_callback' => 'flat_commerce_sanitize_number_range',
        'validate_callback' => 'flat_commerce_validate_social_media_number'
    ) );

    $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_social_media_number]', array(
        'active_callback'   => 'flat_commerce_is_bottom_section_social_media_enabled',
        'label'             => esc_html__( 'Enter the number of required social media icons', 'flat-commerce' ),
        'description'       => esc_html__( 'Save and refresh the page if No. of social media is changed (Max no of Social Media is 5)', 'flat-commerce' ),
        'priority'          => '80',
        'input_attrs'       => array(
            'style'           => 'width: 45px;',
            'min'             => 0,
            'max'             => 5,
            'step'            => 1,
            ),
        'section'           => 'flat_commerce_bottom_section_settings',
        'settings'          => 'flat_commerce_theme_options[bottom_section_social_media_number]',
        'type'              => 'number',
    ) );

    //loop for featured post content
    for ( $i=1; $i <=  $options['bottom_section_social_media_number'] ; $i++ ) {
        // Icon option
        $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_social_media_icon'. $i .']', array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_key',
        ) );

        $flat_commerce_get_social_icons_list = flat_commerce_get_social_icons_list();

        $choices = array();

        foreach ( $flat_commerce_get_social_icons_list as $flat_commerce_get_social_icons_list ) {
            $choices[$flat_commerce_get_social_icons_list['genericon_class']] = $flat_commerce_get_social_icons_list['label'];
        }

        $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_social_media_icon'. $i .']'. $i, array(
            'active_callback'   => 'flat_commerce_is_bottom_section_social_media_enabled',
            'label'             => esc_html__( 'Social Media', 'flat-commerce' ) . ' ' . $i ,
            'priority'          =>  '8' . $i,
            'section'           => 'flat_commerce_bottom_section_settings',
            'settings'          => 'flat_commerce_theme_options[bottom_section_social_media_icon'. $i .']',
            'type'              => 'select',
            'choices'           => $choices,
            'input_attrs'       => array(
                'style'             => 'width: 40px;'
                ),
            )
        );

        //icon url
        $wp_customize->add_setting( 'flat_commerce_theme_options[bottom_section_social_media_url'. $i .']', array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_url',
        ) );

        $wp_customize->add_control( 'flat_commerce_theme_options[bottom_section_social_media_url'. $i .']'. $i, array(
            'active_callback'   => 'flat_commerce_is_bottom_section_social_media_enabled',
            'label'             => esc_html__( 'URL', 'flat-commerce' ) . ' ' . $i ,
            'priority'          =>  '8' .$i,
            'section'           => 'flat_commerce_bottom_section_settings',
            'settings'          => 'flat_commerce_theme_options[bottom_section_social_media_url'. $i .']',
            'type'              => 'url',
            )
        );
}