<?php
/**
 * The main template for implementing Theme/Customzer Options
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}

/**
 * Implements flat-commerce theme options into Theme Customizer.
 *
 * @param $wp_customize Theme Customizer object
 * @return void
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_customize_register( $wp_customize ) {
	$wp_customize->get_setting( 'blogname' )->transport			= 'postMessage';

	/**
  	* Set priority of blogname (Site Title) to 1.
  	*  Strangly, if more than two options is added, Site title is moved below Tagline. This rectifies this issue.
  	*/
	$wp_customize->get_control( 'blogname' )->priority			= 1;

	$wp_customize->get_setting( 'blogdescription' )->transport	= 'postMessage';

	$options  = flat_commerce_get_theme_options();

	$defaults = flat_commerce_get_default_theme_options();

	//Custom Controls
	require get_template_directory() . '/inc/customizer-includes/custom-controls.php';

	if ( 4.5 > get_bloginfo( 'version' ) ) {
		// Custom Logo (added to Site Title and Tagline section in Theme Customizer)
		$wp_customize->add_setting( 'flat_commerce_theme_options[logo]', array(
			'capability'        => 'edit_theme_options',
			'default'           => $defaults['logo'],
			'sanitize_callback' => 'flat_commerce_sanitize_image'
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'logo', array(
			'label'    			=> esc_html__( 'Logo', 'flat-commerce' ),
			'priority' 			=> 100,
			'section'  			=> 'title_tagline',
			'settings' 			=> 'flat_commerce_theme_options[logo]',
	    ) ) );

		$wp_customize->add_setting( 'flat_commerce_theme_options[logo_alt_text]', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['logo_alt_text'],
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( 'flat_commerce_theme_options[logo_alt_text]', array(
			'label'    			=> esc_html__( 'Logo Alt Text', 'flat-commerce' ),
			'priority'			=> 102,
			'section' 			=> 'title_tagline',
			'settings' 			=> 'flat_commerce_theme_options[logo_alt_text]',
			'type'     			=> 'text',
		) );
	}


	$wp_customize->add_setting( 'flat_commerce_theme_options[move_title_tagline]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['move_title_tagline'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[move_title_tagline]', array(
		'label'    			=> esc_html__( 'Check to move Site Title and Tagline before logo', 'flat-commerce' ),
		'priority' 			=> 103,
		'section'  			=> 'title_tagline',
		'settings' 			=> 'flat_commerce_theme_options[move_title_tagline]',
		'type'     			=> 'checkbox',
	) );
	// Custom Logo End

	//topbar
	$wp_customize->add_section( 'flat_commerce_topbar_options', array(
		'title'    			=> esc_html__( 'Topbar Sections', 'flat-commerce' ),
		'priority' 			=> 40,

	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[enable_topbar]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['enable_topbar'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[enable_topbar]', array(
		'label'    			=> esc_html__( 'Check to enable topbar', 'flat-commerce' ),
		'priority' 			=> 103,
		'section'  			=> 'flat_commerce_topbar_options',
		'settings' 			=> 'flat_commerce_theme_options[enable_topbar]',
		'type'     			=> 'checkbox',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[topbar_location]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['topbar_location'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[topbar_location]', array(
		'label'    			=> esc_html__( 'Location', 'flat-commerce' ),
		'active_callback'	=> 'flat_commerce_is_topbar_enable',
		'priority' 			=> 103,
		'section'  			=> 'flat_commerce_topbar_options',
		'settings' 			=> 'flat_commerce_theme_options[topbar_location]',
		'type'     			=> 'text',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[topbar_contact]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['topbar_contact'],
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[topbar_contact]', array(
		'label'    			=> esc_html__( 'Contact', 'flat-commerce' ),
		'active_callback'	=> 'flat_commerce_is_topbar_enable',
		'priority' 			=> 103,
		'section'  			=> 'flat_commerce_topbar_options',
		'settings' 			=> 'flat_commerce_theme_options[topbar_contact]',
		'type'     			=> 'text',
	) );

	// topbar Section custom note
	$wp_customize->add_setting( 'flat_commerce_theme_options[topbar_custom_note]', array(
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Flat_Commerce_Note_Control( $wp_customize, 'flat_commerce_theme_options[topbar_custom_note]', array(
		'label'           	=> esc_html__( 'Social Links For Topbar ', 'flat-commerce' ),
		'priority' 			=> 103,
		'section'         	=> 'flat_commerce_topbar_options',
		'active_callback' 	=> 'flat_commerce_is_topbar_enable',
		'type'            	=> 'description',
	) ) );

	// topbar social Section enable setting and control.
	$wp_customize->add_setting( 'flat_commerce_theme_options[topbar_social_enable]', array(
		'sanitize_callback'	=> 'flat_commerce_sanitize_checkbox',
		'default'          	=> $options['topbar_social_enable'],
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[topbar_social_enable]', array(
		'label'            	=> esc_html__( 'Enable Social Icon', 'flat-commerce' ),
		'priority' 			=> 103,
		'section'          	=> 'flat_commerce_topbar_options',
		'active_callback' 	=> 'flat_commerce_is_topbar_enable',
		'type'             	=> 'checkbox',
	) );

	//loop for featured post content
    for ( $i=1; $i <= 5 ; $i++ ) {
        // Icon option
        $wp_customize->add_setting( 'flat_commerce_theme_options[topbar_social_media_icon'. $i .']', array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'sanitize_key',
            'default'          	=> $options['topbar_social_media_icon' . $i],
        ) );

        $flat_commerce_get_socials = flat_commerce_get_social_icons_list();

        $choices = array();

        foreach ( $flat_commerce_get_socials as $flat_commerce_get_social ) {
            $choices[$flat_commerce_get_social['genericon_class']] = $flat_commerce_get_social['label'];
        }

        $wp_customize->add_control( 'flat_commerce_theme_options[topbar_social_media_icon'. $i .']'. $i, array(
            'active_callback'   => 'flat_commerce_is_topbar_social_enable',
            'label'             => esc_html__( 'Social Media', 'flat-commerce' ) . ' ' . $i ,
            'priority'          =>  103,
            'section'           => 'flat_commerce_topbar_options',
            'settings'          => 'flat_commerce_theme_options[topbar_social_media_icon'. $i .']',
            'type'              => 'select',
            'choices'           => $choices,
            'input_attrs'       => array(
                'style'             => 'width: 40px;'
                ),
            )
        );

        //icon url
        $wp_customize->add_setting( 'flat_commerce_theme_options[topbar_social_media_url'. $i .']', array(
            'capability'        => 'edit_theme_options',
            'sanitize_callback' => 'esc_url',
            'default'          	=> $options['topbar_social_media_url' . $i],
        ) );

        $wp_customize->add_control( 'flat_commerce_theme_options[topbar_social_media_url'. $i .']'. $i, array(
            'active_callback'   => 'flat_commerce_is_topbar_social_enable',
            'label'             => esc_html__( 'URL', 'flat-commerce' ) . ' ' . $i ,
            'priority'          =>  103,
            'section'           => 'flat_commerce_topbar_options',
            'settings'          => 'flat_commerce_theme_options[topbar_social_media_url'. $i .']',
            'input_attrs'	=> array(
				'placeholder'	=> esc_attr__( 'www.facebook.com', 'flat-commerce' ),
			),
            'type'              => 'url',
            )
        );
	}

	// Add color setting and control.
	$wp_customize->add_setting( 'flat_commerce_theme_options[topbar_color_layout]', array(
		'default'           => $options['topbar_color_layout'],
		'sanitize_callback' => 'sanitize_hex_color',
	) );

	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'flat_commerce_theme_options[topbar_color_layout]', array(
		'label'             => esc_html__( 'Topbar Color Layout', 'flat-commerce' ),
		'section'           => 'colors',
	) ) );

	// Homepage (Static ) setting and control.
	$wp_customize->add_setting( 'flat_commerce_theme_options[enable_frontpage_content]', array(
		'sanitize_callback'   => 'flat_commerce_sanitize_checkbox',
		'default'             => $options['enable_frontpage_content'],
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[enable_frontpage_content]', array(
		'label'       	=> esc_html__( 'Enable Content', 'flat-commerce' ),
		'description' 	=> esc_html__( 'Check to enable content on static front page only.', 'flat-commerce' ),
		'section'     	=> 'static_front_page',
		'type'        	=> 'checkbox',
	) );

	// Header Options (added to Header section in Theme Customizer)
	require get_template_directory() . '/inc/customizer-includes/header-options.php';


   //Additional Menu Options
	$wp_customize->add_section( 'flat_commerce_menu_options', array(
		'description'		=> esc_html__( 'Extra Menu Options Specific To This Theme', 'flat-commerce' ),
		'priority' 			=> 1,
		'title'    			=> esc_html__( 'Additional Menu Options', 'flat-commerce' ),
		'panel'				=> 'nav_menus'
	) );

	// enable account
	$wp_customize->add_setting( 'flat_commerce_theme_options[primary_menu_position]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['primary_menu_position'],
		'sanitize_callback' => 'flat_commerce_sanitize_select',
		'transport'			=> 'refresh',
	) );

	$primary_menu_position_options = flat_commerce_primary_menu_position_options();
	$choices = array();

	foreach ( $primary_menu_position_options as $primary_menu_position_option ) {

		$choices[$primary_menu_position_option['value']] = $primary_menu_position_option['label'];
	}

	$wp_customize->add_control( 'flat_commerce_theme_options[primary_menu_position]', array(
		'label'    			=> esc_html__( 'Primary menu Position', 'flat-commerce' ),
		'section'  			=> 'flat_commerce_menu_options',
		'settings' 			=> 'flat_commerce_theme_options[primary_menu_position]',
		'type'     			=> 'select',
		'choices'			=> $choices,
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[primary_menu_disable]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['primary_menu_disable'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[primary_menu_disable]', array(
		'label'   			=> esc_html__( 'Check to disable Primary Menu', 'flat-commerce' ),
		'section'  			=> 'flat_commerce_menu_options',
		'settings' 			=> 'flat_commerce_theme_options[primary_menu_disable]',
		'type'     			=> 'checkbox',
	) );

	// disable search
	$wp_customize->add_setting( 'flat_commerce_theme_options[disable_search_on_primary_menu]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['disable_search_on_primary_menu'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
		'transport'			=> 'refresh',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[disable_search_on_primary_menu]', array(
		'label'    			=> esc_html__( 'Check to remove search box on Primary menu', 'flat-commerce' ),
		'section'  			=> 'flat_commerce_menu_options',
		'settings' 			=> 'flat_commerce_theme_options[disable_search_on_primary_menu]',
		'type'     			=> 'checkbox',
	) );

	// enable cart
	$wp_customize->add_setting( 'flat_commerce_theme_options[enable_cart_on_primary_menu]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['enable_cart_on_primary_menu'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
		'transport'			=> 'refresh',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[enable_cart_on_primary_menu]', array(
		'label'    			=> esc_html__( 'Check to add cart on Primary menu', 'flat-commerce' ),
		'section'  			=> 'flat_commerce_menu_options',
		'settings' 			=> 'flat_commerce_theme_options[enable_cart_on_primary_menu]',
		'type'     			=> 'checkbox',
	) );

	// enable account
	$wp_customize->add_setting( 'flat_commerce_theme_options[enable_account_on_primary_menu]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['enable_account_on_primary_menu'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
		'transport'			=> 'refresh',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[enable_account_on_primary_menu]', array(
		'label'    			=> esc_html__( 'Check to add account on Primary menu', 'flat-commerce' ),
		'section'  			=> 'flat_commerce_menu_options',
		'settings' 			=> 'flat_commerce_theme_options[enable_account_on_primary_menu]',
		'type'     			=> 'checkbox',
	) );


	//Theme Options
	require get_template_directory() . '/inc/customizer-includes/theme-options.php';

	//Featured Product Slider
	require get_template_directory() . '/inc/customizer-includes/frontpage-blog.php';

	//About us 
	require get_template_directory() . '/inc/customizer-includes/bottom-section.php';
	
	//Logo slider
	require get_template_directory() . '/inc/customizer-includes/logo-slider.php';

	//Front page widget
	require get_template_directory() . '/inc/customizer-includes/frontpage-widget.php';

	//Featured Slider
	require get_template_directory() . '/inc/customizer-includes/featured-slider.php';

	//Promotional Headline
	require get_template_directory() . '/inc/customizer-includes/promotional-headline.php';

	//check if woocommerce plugin is activated
	if( class_exists( 'WooCommerce' )){

		//Featured Product Slider
		require get_template_directory() . '/inc/customizer-includes/product-slider.php';

		//Recent Products
		require get_template_directory() . '/inc/customizer-includes/recent-products.php';

		//Featured Content Setting
		require get_template_directory() . '/inc/customizer-includes/featured-product.php';
	}

	//Social Links
	require get_template_directory() . '/inc/customizer-includes/social-icons.php';

	// Reset all settings to default
	$wp_customize->add_section( 'flat_commerce_reset_all_settings', array(
		'description'		=> esc_html__( 'Caution: Reset all settings to default. Refresh the page after save to view full effects.', 'flat-commerce' ),
		'priority' 			=> 700,
		'title'    			=> esc_html__( 'Reset all settings', 'flat-commerce' ),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[reset_all_settings]', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults['reset_all_settings'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
		'transport'            => 'postMessage',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[reset_all_settings]', array(
		'label'    			=> esc_html__( 'Check to reset all settings to default', 'flat-commerce' ),
		'section'  			=> 'flat_commerce_reset_all_settings',
		'settings' 			=> 'flat_commerce_theme_options[reset_all_settings]',
		'type'     			=> 'checkbox',
	) );
	// Reset all settings to default end


	//Important Links
	$wp_customize->add_section( 'important_links', array(
		'priority' 			=> 999,
		'title'   	 		=> esc_html__( 'Important Links', 'flat-commerce' ),
	) );

	/**
	 * Has dummy Sanitizaition function as it contains no value to be sanitized
	 */
	$wp_customize->add_setting( 'important_links', array(
		'sanitize_callback'	=> 'flat_commerce_sanitize_important_link',
	) );

	$wp_customize->add_control( new Flat_Commerce_Important_Links( $wp_customize, 'important_links', array(
		'label'   			=> esc_html__( 'Important Links', 'flat-commerce' ),
		'section'  			=> 'important_links',
		'settings' 			=> 'important_links',
		'type'     			=> 'important_links',
    ) ) );
    //Important Links End
}
add_action( 'customize_register', 'flat_commerce_customize_register' );

/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously for flat-commerce.
 * And flushes out all transient data on preview
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_customize_preview() {
	wp_enqueue_script( 'flat_commerce_customizer', get_template_directory_uri() . '/js/flat-commerce-customizer.min.js', array( 'customize-preview' ), '20120827', true );

	//Flush transients
	flat_commerce_flush_transients();
}
add_action( 'customize_preview_init', 'flat_commerce_customize_preview' );


//Active callbacks for customizer
require get_template_directory() . '/inc/customizer-includes/active-callbacks.php';

//Sanitize functions for customizer
require get_template_directory() . '/inc/customizer-includes/sanitize-functions.php';

//partial refresh functions for customizer
require get_template_directory() . '/inc/customizer-includes/partial-refresh.php';

//Validate functions for customizer
require get_template_directory() . '/inc/customizer-includes/validate-functions.php';

/**
 * Reset all settings to default
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_reset_all_settings() {
	$options = flat_commerce_get_theme_options(); // get theme options
	if ( $options['reset_all_settings'] == 1 ) {
        // Set default values
        set_theme_mod( 'flat_commerce_theme_options', flat_commerce_get_default_theme_options() );

        // Remove background color and image
        remove_theme_mod( 'background_color' );
        remove_theme_mod( 'background_image' );
        remove_theme_mod( 'background_repeat' );
        remove_theme_mod( 'background_position_x' );
        remove_theme_mod( 'background_attachment' );
        remove_theme_mod( 'header_textcolor' );

        // Remove header image
        remove_theme_mod( 'header_image' );
        remove_theme_mod( 'header_image_data' );

        // Flush out all transients	on reset
        flat_commerce_flush_transients();
    }
    else {
        return false;
    }
}
add_action( 'customize_save_after', 'flat_commerce_reset_all_settings' );