<?php
/**
 * The template for adding Featured Product Content Settings in Customizer
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}
	// Featured Product Content Options
	if ( 4.3 > get_bloginfo( 'version' ) ) {
		$wp_customize->add_panel( 'flat_commerce_featured_product_content_options', array(
		    'capability'     => 'edit_theme_options',
			'description'    => esc_html__( 'Options for Featured Product Content', 'flat-commerce' ),
		    'priority'       => 500,
		    'title'    		 => esc_html__( 'Featured Product', 'flat-commerce' ),
		) );


		$wp_customize->add_section( 'flat_commerce_featured_product_content_settings', array(
			'panel'			=> 'flat_commerce_featured_product_content_options',
			'priority'		=> 1,
			'title'			=> esc_html__( 'Featured Product Content Options', 'flat-commerce' ),
		) );
	}
	else {
		$wp_customize->add_section( 'flat_commerce_featured_product_content_settings', array(
			'priority'      => 500,
			'title'			=> esc_html__( 'Featured Product', 'flat-commerce' ),
		) );
	}

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_option]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_product_content_option'],
		'sanitize_callback' => 'flat_commerce_sanitize_select',
	) );

	$flat_commerce_featured_slider_content_options = flat_commerce_featured_slider_content_options();
	$choices = array();
	foreach ( $flat_commerce_featured_slider_content_options as $flat_commerce_featured_slider_content_option ) {
		$choices[$flat_commerce_featured_slider_content_option['value']] = $flat_commerce_featured_slider_content_option['label'];
	}

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_product_content_option]', array(
		'choices'  	=> $choices,
		'label'    	=> esc_html__( 'Enable Featured Product Content on', 'flat-commerce' ),
		'priority'	=> '1',
		'section'  	=> 'flat_commerce_featured_product_content_settings',
		'settings' 	=> 'flat_commerce_theme_options[featured_product_content_option]',
		'type'	  	=> 'select',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_position]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_product_content_position'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_product_content_position]', array(
		'active_callback'	=> 'flat_commerce_is_featured_product_active',
		'label'		=> esc_html__( 'Check to Move above Footer', 'flat-commerce' ),
		'priority'	=> '3',
		'section'  	=> 'flat_commerce_featured_product_content_settings',
		'settings'	=> 'flat_commerce_theme_options[featured_product_content_position]',
		'type'		=> 'checkbox',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_background]', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback' => 'flat_commerce_sanitize_image'
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'flat_commerce_theme_options[featured_product_content_background]', array(
		'description'	=> esc_html__( 'The recommended size for the image is 1800px wide by 600px high.', 'flat-commerce' ),
		'active_callback'	=> 'flat_commerce_is_featured_product_active',
		'label'		=> esc_html__( 'Featured Product Background Image', 'flat-commerce' ),
		'priority'	=> '4',
		'section'  	=> 'flat_commerce_featured_product_content_settings',
		'settings'	=> 'flat_commerce_theme_options[featured_product_content_background]',
	) ) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_headline]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_product_content_headline'],
		'transport'			=> 'postMessage',
		'sanitize_callback'	=> 'wp_kses_post',
	) );

	// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'flat_commerce_theme_options[featured_product_content_headline]', array(
			'selector'            => '#featured .col .featured-time span.entry-title',
			'render_callback'     => 'flat_commerce_customize_partial_featured_product_content_headline',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
		) );
	}

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_product_content_headline]' , array(
		'active_callback' => 'flat_commerce_is_featured_product_active',
		'description'     => esc_html__( 'Leave field empty if you want to remove Headline', 'flat-commerce' ),
		'label'           => esc_html__( 'Headline for Featured Product Content', 'flat-commerce' ),
		'priority'        => '5',
		'section'         => 'flat_commerce_featured_product_content_settings',
		'settings'        => 'flat_commerce_theme_options[featured_product_content_headline]',
		'type'            => 'text',
		)
	);

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_subheadline]', array(
		'capability'        => 'edit_theme_options',
		'default'           => $defaults['featured_product_content_subheadline'],
		'sanitize_callback' => 'flat_commerce_sanitize_select',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_product_content_subheadline]' , array(
		'active_callback' => 'flat_commerce_is_featured_product_active',
		'description'     => esc_html__( 'Leave field empty if you want to remove Sub-headline', 'flat-commerce' ),
		'label'           => esc_html__( 'Sub-headline for Featured Product Content', 'flat-commerce' ),
		'priority'        => '6',
		'section'         => 'flat_commerce_featured_product_content_settings',
		'settings'        => 'flat_commerce_theme_options[featured_product_content_subheadline]',
		'type'            => 'radio',
		'choices'         => array(
			'text'            => 'Text',
			'image'           => 'Image',
		),
	) );

	// Subheadline text
	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_subheadline_text]', array(
    	'default' => '',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_product_content_subheadline_text]', array(
		'label'           => 'Text',
		'priority'        => '6.1',
		'section'         => 'flat_commerce_featured_product_content_settings',
		'type'            => 'text',
		'active_callback' => 'is_featured_product_content_subheadline_choice_set',
	) );

	// Subheadline image
	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_subheadline_image]', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( new WP_Customize_Cropped_Image_Control( $wp_customize, 'flat_commerce_theme_options[featured_product_content_subheadline_image]', array(
		'priority'        => '6.2',
		'label'           => 'Image',
		'section'         => 'flat_commerce_featured_product_content_settings',
		'active_callback' => 'is_featured_product_content_subheadline_choice_set',
		'flex_width'  => true, // Allow any width, making the specified value recommended. False by default.
	    'flex_height' => false, // Require the resulting image to be exactly as tall as the height attribute (default).
	    'width'       => 440,
	    'height'      => 90,
	) ) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_type]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_product_content_type'],
		'sanitize_callback'	=> 'sanitize_key',
	) );

	$flat_commerce_featured_product_content_types = flat_commerce_featured_product_content_types();
	$choices = array();
	foreach ( $flat_commerce_featured_product_content_types as $flat_commerce_featured_product_content_type ) {
		$choices[$flat_commerce_featured_product_content_type['value']] = $flat_commerce_featured_product_content_type['label'];
	}

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_product_content_type]', array(
		'active_callback'	=> 'flat_commerce_is_featured_product_active',
		'choices'  	=> $choices,
		'label'    	=> esc_html__( 'Select Content Type', 'flat-commerce' ),
		'priority'	=> '7',
		'section'  	=> 'flat_commerce_featured_product_content_settings',
		'settings' 	=> 'flat_commerce_theme_options[featured_product_content_type]',
		'type'	  	=> 'select',
	) );

	// Enable link in the featured products
	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_url_option]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_product_content_url_option'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_product_content_url_option]', array(
		'active_callback'	=> 'flat_commerce_is_featured_product_active',
		'label'		=> esc_html__( 'Check to diable link on the featured products', 'flat-commerce' ),
		'priority'	=> '7',
		'section'  	=> 'flat_commerce_featured_product_content_settings',
		'settings'	=> 'flat_commerce_theme_options[featured_product_content_url_option]',
		'type'		=> 'checkbox',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_number]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_product_content_number'],
		'sanitize_callback'	=> 'flat_commerce_sanitize_number_range',
		'validate_callback'	=> 'flat_commerce_validate_product_content_number'
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_product_content_number]' , array(
		'active_callback'	=> 'flat_commerce_is_demo_featured_product_content_inactive',
		'description'	=> esc_html__( 'Save and refresh the page if number of Featured Product Content is changed (Max no of Featured Product Content is 6)', 'flat-commerce' ),
		'input_attrs' 	=> array(
            'style' => 'width: 45px;',
            'min'   => 1,
            'max'   => 6,
            'step'  => 1,
        	),
		'label'    		=> esc_html__( 'Number of Featured Product Content', 'flat-commerce' ),
		'priority'		=> '8',
		'section'  		=> 'flat_commerce_featured_product_content_settings',
		'settings' 		=> 'flat_commerce_theme_options[featured_product_content_number]',
		'type'	   		=> 'number',
		)
	);

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_layout]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['featured_product_content_layout'],
		'sanitize_callback'	=> 'flat_commerce_sanitize_number_range',
	) );


	$flat_commerce_featured_product_layout_options = flat_commerce_featured_product_layout_options();
	$choices = array();
	foreach ( $flat_commerce_featured_product_layout_options as $flat_commerce_featured_product_layout_options ) {
		$choices[$flat_commerce_featured_product_layout_options['value']] = $flat_commerce_featured_product_layout_options['label'];
	}

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_product_content_layout]', array(
		'active_callback'	=> 'flat_commerce_is_demo_featured_product_content_inactive',
		'label'    	=> esc_html__( 'Number of columns', 'flat-commerce' ),
		'priority'	=> '6.3',
		'section'  	=> 'flat_commerce_featured_product_content_settings',
		'settings' 	=> 'flat_commerce_theme_options[featured_product_content_layout]',
		'type'	  	=> 'select',
		'choices'   => $choices,
	) );


	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_select_category]', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'flat_commerce_sanitize_category_list',
	) );

	$wp_customize->add_control( new Flat_Commerce_Customize_Dropdown_Product_Categories_Control( $wp_customize, 'flat_commerce_featured_product_content_select_category', array(
        'active_callback'	=> 'flat_commerce_is_featured_category_content_active',
        'label'   	=> esc_html__( 'Select Categories', 'flat-commerce' ),
        'name' 		=> 'flat_commerce_theme_options[featured_product_content_select_category]',
        'section'  	=> 'flat_commerce_featured_product_content_settings',
        'settings' 	=> 'flat_commerce_theme_options[featured_product_content_select_category]',
    ) ) );

	$priority	=	11;

	//loop for featured post content
	for ( $i=1; $i <=  $options['featured_product_content_number'] ; $i++ ) {
		$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_post_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'flat_commerce_sanitize_page',
		) );

		$wp_customize->add_control( 'flat_commerce_featured_product_content_post_'. $i, array(
			'active_callback'	=> 'flat_commerce_is_featured_post_content_active',
			'input_attrs' => array(
            	'style' => 'width: 40px;'
        	),
			'label'    	=> esc_html__( 'Featured Post', 'flat-commerce' ) . ' ' . $i ,
			'priority'	=>  '4' . $i,
			'section'  	=> 'flat_commerce_featured_product_content_settings',
			'settings' 	=> 'flat_commerce_theme_options[featured_product_content_post_'. $i .']',
			'type'	   	=> 'text',
			)
		);

		$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_product_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'flat_commerce_sanitize_page',
		) );

		$wp_customize->add_control( 'flat_commerce_featured_product_content_product_'. $i, array(
			'active_callback'	=> 'flat_commerce_is_featured_product_content_active',
			'input_attrs' => array(
            	'style' => 'width: 40px;'
        	),
			'label'    	=> esc_html__( 'Featured Product', 'flat-commerce' ) . ' ' . $i ,
			'description' => esc_html__( 'Enter Product ID', 'flat-commerce' ),
			'priority'	=>  '4' . $i,
			'section'  	=> 'flat_commerce_featured_product_content_settings',
			'settings' 	=> 'flat_commerce_theme_options[featured_product_content_product_'. $i .']',
			'type'	   	=> 'text',
			)
		);

		$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_page_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'flat_commerce_sanitize_page',
		) );

		$wp_customize->add_control( 'flat_commerce_featured_product_content_page_'. $i .'', array(
			'active_callback'	=> 'flat_commerce_is_featured_page_content_active',
			'label'    	=> esc_html__( 'Featured Page', 'flat-commerce' ) . ' ' . $i ,
			'priority'	=> '5' . $i,
			'section'  	=> 'flat_commerce_featured_product_content_settings',
			'settings' 	=> 'flat_commerce_theme_options[featured_product_content_page_'. $i .']',
			'type'	   	=> 'dropdown-pages',
		) );

		if( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
			$priority++;

		$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_note_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Flat_Commerce_Note_Control( $wp_customize, 'featured_product_content_note_'. $i, array(
			'active_callback'	=> 'flat_commerce_is_featured_image_content_active',
	        'label'		=> esc_html__( 'Featured Product Content #', 'flat-commerce' ) .  $i,
			'priority'	=> $priority . '.' . $i,
	        'section'  	=> 'flat_commerce_featured_product_content_settings',
	        'settings'	=> 'flat_commerce_theme_options[featured_product_content_note_'. $i .']',
	        'type'     	=> 'description',
   		) ) );

		$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_image_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'flat_commerce_sanitize_image',
		) );

		$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'featured_product_content_image_'. $i , array(
			'active_callback'	=> 'flat_commerce_is_featured_image_content_active',
			'label'		=> esc_html__( 'Image', 'flat-commerce' ),
	        'priority'	=> $priority . '.' . $i .$i,
			'section'   => 'flat_commerce_featured_product_content_settings',
	        'settings'  => 'flat_commerce_theme_options[featured_product_content_image_'. $i .']',
		) ) );

		$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_link_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'esc_url_raw',
		) );

		$wp_customize->add_control(  'flat_commerce_theme_options[featured_product_content_link_'. $i .']', array(
			'active_callback'	=> 'flat_commerce_is_featured_image_content_active',
			'label'		=> esc_html__( 'Link', 'flat-commerce' ),
	        'priority'	=> $priority . '.' .$i . $i  . $i ,
			'section'   => 'flat_commerce_featured_product_content_settings',
	        'settings'  => 'flat_commerce_theme_options[featured_product_content_link_'. $i .']',
		) );

		$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_target_'. $i .']', array(
	        'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'flat_commerce_sanitize_checkbox',
		) );

		$wp_customize->add_control(  'flat_commerce_theme_options[featured_product_content_target_'. $i .']', array(
			'active_callback'	=> 'flat_commerce_is_featured_image_content_active',
			'label'		=> esc_html__( 'Check to Open Link in New Window/Tab', 'flat-commerce' ),
	        'priority'	=> $priority . '.' .$i  .$i  . $i . $i,
			'section'   => 'flat_commerce_featured_product_content_settings',
	        'settings'  => 'flat_commerce_theme_options[featured_product_content_target_'. $i .']',
			'type'		=> 'checkbox',
	    ) );

	    $wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_content_title_'. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control(  'flat_commerce_theme_options[featured_product_content_title_'. $i .']', array(
			'active_callback'	=> 'flat_commerce_is_featured_image_content_active',
			'label'		=> esc_html__( 'Title', 'flat-commerce' ),
	       'priority'	=> $priority . '.' .$i .  $i.  $i .$i . $i,
			'section'   => 'flat_commerce_featured_product_content_settings',
	       'settings'  => 'flat_commerce_theme_options[featured_product_content_title_'. $i .']',
			'type'		=> 'text',
	    ) );
	}
// Featured Product Content Setting End