<?php
/**
 * The template for adding Featured Slider Options in Customizer
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}
$wp_customize->add_panel( 'flat_commerce_featured_slider', array(
	'priority'      => 200,
	'title'			=> esc_html__( 'Featured Slider', 'flat-commerce' ),
) );

$wp_customize->add_section( 'flat_commerce_featured_slider_control', array(
	'panel' 			=> 'flat_commerce_featured_slider',
	'priority'      => 10,
	'title'			=> esc_html__( 'Featured Slider Control', 'flat-commerce' ),
) );

$wp_customize->add_section( 'flat_commerce_featured_slider_type', array(
	'panel' 			=> 'flat_commerce_featured_slider',
	'priority'      => 20,
	'title'			=> esc_html__( 'Featured Slider Type', 'flat-commerce' ),
	'description' 	=> esc_html__( 'Recommended featured image size 1366 X 585 px', 'flat-commerce' ),
) );

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_option]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_option'],
	'sanitize_callback' => 'flat_commerce_sanitize_select',
) );

$featured_slider_content_options = flat_commerce_featured_slider_content_options();
$choices = array();

foreach ( $featured_slider_content_options as $featured_slider_content_option ) {

	$choices[$featured_slider_content_option['value']] = $featured_slider_content_option['label'];

}

$wp_customize->add_control( 'flat_commerce_theme_options[featured_slider_option]', array(
	'label'    			=> esc_html__( 'Enable Slider on', 'flat-commerce' ),
	'priority'			=> '1',
	'section'  			=> 'flat_commerce_featured_slider_control',
	'settings' 			=> 'flat_commerce_theme_options[featured_slider_option]',
	'type'    			=> 'select',
	'choices'   		=> $choices,
));

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slide_transition_effect]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slide_transition_effect'],
	'sanitize_callback'	=> 'flat_commerce_sanitize_select',
));

$flat_commerce_featured_slide_transition_effects = flat_commerce_featured_slide_transition_effects();
$choices = array();

foreach ( $flat_commerce_featured_slide_transition_effects as $flat_commerce_featured_slide_transition_effect ) {
	$choices[$flat_commerce_featured_slide_transition_effect['value']] = $flat_commerce_featured_slide_transition_effect['label'];
}

$wp_customize->add_control( 'flat_commerce_theme_options[featured_slide_transition_effect]' , array(
	'active_callback'	=> 'flat_commerce_is_slider_active',
	'label'				=> esc_html__( 'Transition Effect', 'flat-commerce' ),
	'priority'			=> '2',
	'section'  			=> 'flat_commerce_featured_slider_control',
	'settings' 			=> 'flat_commerce_theme_options[featured_slide_transition_effect]',
	'type'	  			=> 'select',
	'choices'  			=> $choices,
));

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slide_transition_delay]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slide_transition_delay'],
	'sanitize_callback'	=> 'flat_commerce_sanitize_number_range',
	'validate_callback' => 'flat_commerce_validate_slide_transition_delay',
));

$wp_customize->add_control( 'flat_commerce_theme_options[featured_slide_transition_delay]' , array(
	'active_callback'	=> 'flat_commerce_is_slider_active',
	'description'		=> esc_html__( 'seconds(s)', 'flat-commerce' ),
	'input_attrs' 		=> array(
         'min'   			=> 1,
         'style' 			=> 'width: 60px;'
	),
 	'label'    			=> esc_html__( 'Transition Delay', 'flat-commerce' ),
	'priority'			=> '2.1.1',
	'section'  			=> 'flat_commerce_featured_slider_control',
	'settings' 			=> 'flat_commerce_theme_options[featured_slide_transition_delay]',
	'type'	   			=> 'number',
));

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slide_transition_length]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slide_transition_length'],
	'sanitize_callback'	=> 'flat_commerce_sanitize_number_range',
	'validate_callback'	=> 'flat_commerce_validate_slide_transition_length'
));

$wp_customize->add_control( 'flat_commerce_theme_options[featured_slide_transition_length]' , array(
	'active_callback'	=> 'flat_commerce_is_slider_active',
		'description'	=> esc_html__( 'seconds(s)', 'flat-commerce' ),
		'input_attrs' 	=> array(
			'min'   		=> 1,
			'style' 		=> 'width: 60px;'
		),
		'label'    		=> esc_html__( 'Transition Length', 'flat-commerce' ),
		'priority'		=> '2.1.2.1',
		'section'  		=> 'flat_commerce_featured_slider_control',
		'settings' 		=> 'flat_commerce_theme_options[featured_slide_transition_length]',
		'type'	   		=> 'number',
));

$wp_customize->add_setting( 'flat_commerce_theme_options[enable_slider_captions]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['enable_slider_captions'],
	'sanitize_callback'	=> 'flat_commerce_sanitize_checkbox',
));

$wp_customize->add_control( 'flat_commerce_theme_options[enable_slider_captions]' , array(
	'active_callback'	=> 'flat_commerce_is_slider_active',
		'label'    		=> esc_html__( 'Enable Slider Caption', 'flat-commerce' ),
		'priority'		=> '2.1.2.1',
		'section'  		=> 'flat_commerce_featured_slider_control',
		'settings' 		=> 'flat_commerce_theme_options[enable_slider_captions]',
		'type'			=> 'checkbox',
));

$wp_customize->add_setting( 'flat_commerce_theme_options[slider_overlay]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['slider_overlay'],
	'sanitize_callback'	=> 'flat_commerce_sanitize_number_range',
));

$wp_customize->add_control( 'flat_commerce_theme_options[slider_overlay]' , array(
	'active_callback'	=> 'flat_commerce_is_slider_active',
		'label'    		=> esc_html__( 'Slider Overlay', 'flat-commerce' ),
		'priority'		=> '2.1.2.1',
		'section'  		=> 'flat_commerce_featured_slider_control',
		'settings' 		=> 'flat_commerce_theme_options[slider_overlay]',
		'type'			=> 'number',
		'input_attrs'   => array(
			'min'       => 0.1,
			'max'		=> 0.6,
			'step'		=> 0.1,
			'style'     => 'width: 60px;'
		),
));

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slide_loop]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slide_loop'],
	'sanitize_callback'	=> 'flat_commerce_sanitize_select',
));

$wp_customize->add_control( 'flat_commerce_theme_options[featured_slide_loop]' , array(
	'active_callback' => 'flat_commerce_is_slider_active',
	'description'     => esc_html__( 'If the value is set to INFNITE then the slideshow will loop continuously. Set to SINGLE to loop once.', 'flat-commerce' ),
	'input_attrs'     => array(
	'min'             => 0,
	'style'           => 'width: 60px;'
	),
	'label'           => esc_html__( 'Loop', 'flat-commerce' ),
	'priority'        => '2.1.2',
	'section'         => 'flat_commerce_featured_slider_control',
	'settings'        => 'flat_commerce_theme_options[featured_slide_loop]',
	'type'            => 'select',
	'choices'         => array(
		'single'  => 'Single',
		'infinite' => 'Infinite',
	),
));

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_image_loader]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_image_loader'],
	'sanitize_callback' => 'sanitize_key',
) );

$featured_slider_image_loader_options = flat_commerce_featured_slider_image_loader();
$choices = array();

foreach ( $featured_slider_image_loader_options as $featured_slider_image_loader_option ) {
	$choices[$featured_slider_image_loader_option['value']] = $featured_slider_image_loader_option['label'];
}

$wp_customize->add_control( 'flat_commerce_theme_options[featured_slider_image_loader]', array(
	'active_callback' 	=> 'flat_commerce_is_slider_active',
	'description'     	=> sprintf( esc_html__( 'True: Fixes the height overlap issue. Slideshow will start as soon as two slider are available. Slide may display in random, as image is fetch.%1$sWait: Fixes the height overlap issue.%2$s Slideshow will start only after all images are available.', 'flat-commerce' ), '<br>', '<br>' ),
	'label'           	=> esc_html__( 'Image Loader', 'flat-commerce' ),
	'priority'        	=> '2.1.3',
	'section'         	=> 'flat_commerce_featured_slider_control',
	'settings'        	=> 'flat_commerce_theme_options[featured_slider_image_loader]',
	'type'            	=> 'select',
	'choices'        	=> $choices,
) );

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_link_text]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_link_text'],
	'sanitize_callback'	=> 'sanitize_text_field',
));

$wp_customize->add_control( 'flat_commerce_theme_options[featured_slider_link_text]' , array(
	'active_callback'	=> 'flat_commerce_is_slider_active',
		'label'    		=> esc_html__( 'Link Text', 'flat-commerce' ),
		'description'	=> esc_html__( 'Leave empty to hide Link button', 'flat-commerce' ),
		'priority'		=> '2.1.2.3',
		'section'  		=> 'flat_commerce_featured_slider_control',
		'settings' 		=> 'flat_commerce_theme_options[featured_slider_link_text]',
));

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_button_color]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_button_color'],
	'sanitize_callback'	=> 'sanitize_hex_color',
));

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_button_color]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_button_color'],
	'sanitize_callback'	=> 'sanitize_hex_color',
));


$wp_customize->add_control( new WP_Customize_Color_Control( 
	$wp_customize, 'flat_commerce_theme_options[featured_slider_button_color]' , array(
	'active_callback'	=> 'flat_commerce_is_slider_active',
		'label'    		=> esc_html__( 'Link Button and Slider Pager Color', 'flat-commerce' ),
		'priority'		=> '2.1.2.4',
		'section'  		=> 'flat_commerce_featured_slider_control',
		'settings' 		=> 'flat_commerce_theme_options[featured_slider_button_color]',
) ) );

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_button_color_hover]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_button_color_hover'],
	'sanitize_callback'	=> 'sanitize_hex_color',
));

$wp_customize->add_control( new WP_Customize_Color_Control( 
	$wp_customize, 'flat_commerce_theme_options[featured_slider_button_color_hover]' , array(
	'active_callback'	=> 'flat_commerce_is_slider_active',
		'label'    		=> esc_html__( 'Link Button Hover Color', 'flat-commerce' ),
		'priority'		=> '2.1.2.5',
		'section'  		=> 'flat_commerce_featured_slider_control',
		'settings' 		=> 'flat_commerce_theme_options[featured_slider_button_color_hover]',
) ) );

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_type]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> $defaults['featured_slider_type'],
	'sanitize_callback'	=> 'sanitize_key',
) );

$featured_slider_types = flat_commerce_featured_slider_types();
$choices = array();

foreach ( $featured_slider_types as $featured_slider_type ) {
	$choices[$featured_slider_type['value']] = $featured_slider_type['label'];
}

$wp_customize->add_control( 'flat_commerce_theme_options[featured_slider_type]', array(
	'active_callback' 	=> 'flat_commerce_is_slider_active',
	'label'           	=> esc_html__( 'Select Slider Type', 'flat-commerce' ),
	'priority'        	=> '2.1.3',
	'section'         	=> 'flat_commerce_featured_slider_type',
	'settings'        	=> 'flat_commerce_theme_options[featured_slider_type]',
	'type'            	=> 'select',
	'choices'         	=> $choices,
) );

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slide_number]', array(
	'capability'        => 'edit_theme_options',
	'default'			=> $defaults['featured_slide_number'],
	'sanitize_callback'	=> 'flat_commerce_sanitize_number_range',
	'validate_callback'	=> 'flat_commerce_validate_featured_slide_number'

) );

$wp_customize->add_control( 'flat_commerce_theme_options[featured_slide_number]' , array(
	'active_callback' 	=> 'flat_commerce_is_demo_slider_inactive',
	'description'     	=> esc_html__( 'Save and refresh the page if number of Slides is changed (Maximum number of slides is 10)', 'flat-commerce' ),
	'label'           	=> esc_html__( 'Number of Slides', 'flat-commerce' ),
	'priority'        	=> '2.1.4',
	'section'         	=> 'flat_commerce_featured_slider_type',
	'settings'        	=> 'flat_commerce_theme_options[featured_slide_number]',
	'type'            	=> 'number',
	'input_attrs'     	=> array(
		'style'           	=> 'width: 45px;',
		'min'             	=> 0,
		'max'             	=> 10,
		'step'            	=> 1,
	),
) );

$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_select_category]', array(
	'capability'		=> 'edit_theme_options',
	'default'			=> '',
	'sanitize_callback'	=> 'flat_commerce_sanitize_category_list',
) );

$wp_customize->add_control( new Flat_Commerce_Customize_Dropdown_Categories_Control( $wp_customize, 'flat_commerce_featured_slider_select_category', array(
	'active_callback' => 'flat_commerce_is_category_slider_active',
	'label'           => esc_html__('Select Categories', 'flat-commerce' ),
	'name'            => 'flat_commerce_theme_options[featured_slider_select_category]',
	'priority'        => '100',
	'section'         => 'flat_commerce_featured_slider_type',
	'settings'        => 'flat_commerce_theme_options[featured_slider_select_category]',
	'type'            => 'dropdown-categories',
 ) ) );

 //loop for featured post sliders
$priority	=	'11';
for ( $i=1; $i <=  $options['featured_slide_number'] ; $i++ ) {
	// Product category
	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_product_slider_'.$i.']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback' => 'sanitize_key',
	) );

	$wp_customize->add_control( new Flat_Commerce_Customize_WC_Dropdown_Product_Category( $wp_customize,
		'flat_commerce_theme_options[featured_product_slider_'.$i.']', array(
		'active_callback' 	=> 'flat_commerce_is_featured_product_slider_active_',
		'label'    			=> esc_html__( 'Select Product Category ', 'flat-commerce' ).$i,
		'priority'        =>  '3' . $i,
		'section'  			=> 'flat_commerce_featured_slider_type',
		'type'    			=> 'wc-dropdown-category',
	) ) );

	// Post slider
	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_post_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'flat_commerce_sanitize_page',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_slider_post_'. $i .']', array(
		'active_callback' => 'flat_commerce_is_post_slider_active',
		'label'           => esc_html__( 'Featured Post', 'flat-commerce' ) . ' # ' . $i ,
		'priority'        =>  '3' . $i,
		'section'         => 'flat_commerce_featured_slider_type',
		'settings'        => 'flat_commerce_theme_options[featured_slider_post_'. $i .']',
		'type'            => 'text',
		'input_attrs' 		=> array(
     		'style' 		=> 'width: 80px;'
 		),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_page_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'flat_commerce_sanitize_page',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_slider_page_'. $i .']', array(
		'active_callback' => 'flat_commerce_is_page_slider_active',
		'label'           => esc_html__( 'Featured Page', 'flat-commerce' ) . ' # ' . $i ,
		'priority'        => '3' . $i,
		'section'         => 'flat_commerce_featured_slider_type',
		'settings'        => 'flat_commerce_theme_options[featured_slider_page_'. $i .']',
		'type'            => 'dropdown-pages',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_logo_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'flat_commerce_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'flat_commerce_theme_options[featured_slider_logo_'. $i .']' , array(
		'active_callback' => 'flat_commerce_is_post_and_page_slider_active',
		'label'           => esc_html__( 'Slider Logo #', 'flat-commerce' ). $i,
		'description'	  => esc_html__( 'The recommended size of the image is 120px x 70px.', 'flat-commerce' ),
		'priority'        => '3' . $i,
		'section'         => 'flat_commerce_featured_slider_type',
		'settings'        => 'flat_commerce_theme_options[featured_slider_logo_'. $i .']',
	) ) );

	if( $i > 9 ) // use this condition to make sure 10 comes after 9 priority wise
		$priority++;

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_note_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( new Flat_Commerce_Note_Control( $wp_customize, 'flat_commerce_theme_options[featured_slider_note_'. $i .']', array(
		'active_callback' => 'flat_commerce_is_image_slider_active',
		'label'           => esc_html__( 'Featured Slide #', 'flat-commerce' ) . $i,
		'priority'        => $priority . '.' . $i,
		'section'         => 'flat_commerce_featured_slider_type',
		'settings'        => 'flat_commerce_theme_options[featured_slider_note_'. $i .']',
		'type'            => 'description',
		) ) );


	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_image_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'flat_commerce_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'flat_commerce_theme_options[featured_slider_image_'. $i .']' , array(
		'active_callback' => 'flat_commerce_is_image_slider_active',
		'label'           => esc_html__( 'Image', 'flat-commerce' ),
		'description'		=> esc_html__( 'The recommended size of the image is 1800 x 720px.', 'flat-commerce' ),
		'priority'        => $priority . '.' . $i .$i,
		'section'         => 'flat_commerce_featured_slider_type',
		'settings'        => 'flat_commerce_theme_options[featured_slider_image_'. $i .']',
	) ) );
	
	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_slider_image_logo_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'flat_commerce_sanitize_image',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'flat_commerce_theme_options[featured_slider_image_logo_'. $i .']' , array(
		'active_callback' => 'flat_commerce_is_image_slider_active',
		'label'           => esc_html__( 'Slider Logo #', 'flat-commerce' ). $i,
		'description'	  => esc_html__( 'The recommended size of the image is 120px x 70px.', 'flat-commerce' ),
		'priority'        => $priority . '.' . $i .$i,
		'section'         => 'flat_commerce_featured_slider_type',
		'settings'        => 'flat_commerce_theme_options[featured_slider_image_logo_'. $i .']',
	) ) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_link_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'esc_url_raw',
	) );

	$wp_customize->add_control(  'flat_commerce_theme_options[featured_link_'. $i .']', array(
		'active_callback' => 'flat_commerce_is_image_slider_active',
		'label'           => esc_html__( 'Link', 'flat-commerce' ),
		'priority'        => $priority . '.' .$i . $i  . $i,
		'section'         => 'flat_commerce_featured_slider_type',
		'settings'        => 'flat_commerce_theme_options[featured_link_'. $i .']',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_target_'. $i .']', array(
       'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'flat_commerce_sanitize_checkbox',
	) );

	$wp_customize->add_control(  'flat_commerce_theme_options[featured_target_'. $i .']', array(
		'active_callback' => 'flat_commerce_is_image_slider_active',
		'label'           => esc_html__( 'Check to Open Link in New Window/Tab', 'flat-commerce' ),
		'priority'        => $priority . '.' .$i  .$i  . $i . $i,
		'section'         => 'flat_commerce_featured_slider_type',
		'settings'        => 'flat_commerce_theme_options[featured_target_'. $i .']',
		'type'            => 'checkbox',
    ) );

    $wp_customize->add_setting( 'flat_commerce_theme_options[featured_title_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control(  'flat_commerce_theme_options[featured_title_'. $i .']', array(
		'active_callback' => 'flat_commerce_is_image_slider_active',
		'label'           => esc_html__( 'Title', 'flat-commerce' ),
		'priority'        => $priority . '.' .$i .  $i.  $i .$i . $i,
		'section'         => 'flat_commerce_featured_slider_type',
		'settings'        => 'flat_commerce_theme_options[featured_title_'. $i .']',
		'type'            => 'text',
    ) );

    $wp_customize->add_setting( 'flat_commerce_theme_options[featured_content_'. $i .']', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_content_'. $i .']', array(
		'active_callback' => 'flat_commerce_is_image_slider_active',
		'label'           => esc_html__( 'Content', 'flat-commerce' ),
		'priority'        => $priority . '.' . $i . $i .  $i . $i . $i . $i,
		'section'         => 'flat_commerce_featured_slider_type',
		'settings'        => 'flat_commerce_theme_options[featured_content_'. $i .']',
		'type'            => 'textarea',
    ) );
}
// Featured Slider End