<?php
/**
 * The template for adding About us Content Settings in Customizer
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

$wp_customize->add_section( 'flat_commerce_logo_slider_settings', array(
    'priority'      => 620,
    'title'         => esc_html__( 'Logo Slider', 'flat-commerce' ),
) );

// Enable option.
$wp_customize->add_setting( 'flat_commerce_theme_options[logo_slider_enable_option]', array(
    'default'           => $defaults['logo_slider_enable_option'],
    'sanitize_callback' => 'flat_commerce_sanitize_select',
) );

$logo_slider_enable_options = flat_commerce_bottom_section_enable_options(); //get options to enable about us section

$choices = array();

foreach ( $logo_slider_enable_options as $logo_slider_enable_option ) {
    $choices[ $logo_slider_enable_option['value']] = $logo_slider_enable_option['label'];
}

$wp_customize->add_control( 'flat_commerce_theme_options[logo_slider_enable_option]', array(
    'label'             => esc_html__( 'Enable Logo Slider on', 'flat-commerce' ),
    'priority'          => '10',
    'section'           => 'flat_commerce_logo_slider_settings',
    'type'              => 'select',
    'choices'           => $choices,
) );

// Slider number
$wp_customize->add_setting( 'flat_commerce_theme_options[logo_slider_number]', array(
	'default'			=> $defaults['logo_slider_number'],
	'sanitize_callback'	=> 'flat_commerce_sanitize_number_range',
) );

$wp_customize->add_control( 'flat_commerce_theme_options[logo_slider_number]' , array(
    'active_callback'   => 'flat_commerce_is_logo_slider_active',
	'description'     	=> esc_html__( 'Save and refresh the page if number of Slides is changed (Maximum number of slides is 10)', 'flat-commerce' ),
	'label'           	=> esc_html__( 'Number of Slides', 'flat-commerce' ),
	'section'         	=> 'flat_commerce_logo_slider_settings',
	'type'            	=> 'number',
	'input_attrs'     	=> array(
		'style'           	=> 'width: 45px;',
		'min'             	=> 0,
		'max'             	=> 10,
		'step'            	=> 1,
	),
) );

for ( $i=1; $i <=  $options['logo_slider_number'] ; $i++ ) {
	// Logo Image upload.
	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_logo_slider_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'flat_commerce_theme_options[featured_logo_slider_'.$i.']', array(
		'active_callback' 	=> 'flat_commerce_is_logo_slider_active',
		'label'    			=> esc_html__( 'Select Logo ', 'flat-commerce' ).$i,
		'description'    			=> esc_html__( 'The minimum recommended size for the image is 300px by 300px. If the size is more than that it should be in 1:1 ratio.', 'flat-commerce' ),
		'section'  			=> 'flat_commerce_logo_slider_settings',
	) ) );

	// Logo Image URL upload.
	$wp_customize->add_setting( 'flat_commerce_theme_options[featured_logo_slider_url_'.$i.']', array(
		'sanitize_callback' => 'esc_url_raw',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[featured_logo_slider_url_'.$i.']', array(
		'active_callback' 	=> 'flat_commerce_is_logo_slider_active',
		'label'    			=> esc_html__( 'Logo URL ', 'flat-commerce' ).$i,
		'section'  			=> 'flat_commerce_logo_slider_settings',
		'type'				=> 'url'
	) );
}