<?php
/**
 * The template for adding Product Slider Options in Customizer
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */
if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}
	// add panel
	$wp_customize->add_panel( 'flat_commerce_product_slider_options', array(
	'capability'  			=> 'edit_theme_options',
	'description' 			=> esc_html__( 'Change ( Product Slider -> Select Product Slider Type ) for Custom product slider.', 'flat-commerce'),
	'title'       			=> esc_html__( 'Product Slider Options', 'flat-commerce' ),
	'priority'    			=> 400,
	) );

	// add section
	$wp_customize->add_section( 'flat_commerce_product_slider', array(
	'panel'       			=> 'flat_commerce_product_slider_options',
	'priority'    			=> 400,
	'title'       			=> esc_html__( 'Product Slider', 'flat-commerce' ),
	) );

	// product slide option
	$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_option]', array(
		'capability'        => 'edit_theme_options',
		'default'			=> $defaults['product_slider_option'],
		'sanitize_callback' => 'flat_commerce_sanitize_select',
	) );

	$product_slider_content_options = flat_commerce_get_product_slider_content_options();
	$choices = array();

	foreach ( $product_slider_content_options as $product_slider_content_option ) {

		$choices[$product_slider_content_option['value']] = $product_slider_content_option['label'];

	}

	$wp_customize->add_control( 'flat_commerce_theme_options[product_slider_option]', array(
		'label'    			=> esc_html__( 'Enable Slider on', 'flat-commerce' ),
		'priority'			=> '1.1',
		'section'  			=> 'flat_commerce_product_slider',
		'settings' 			=> 'flat_commerce_theme_options[product_slider_option]',
		'type'    			=> 'select',
		'choices'   		=> $choices,
	) );

	// product slider type
	$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_type_select]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['product_slider_type_select'],
		'sanitize_callback' => 'sanitize_key',
	) );

	$product_slider_types_select = flat_commerce_get_product_slider_type_select();
	$choices = array();

	foreach ( $product_slider_types_select as $product_slider_type_select ) {

		$choices[$product_slider_type_select['value']] = $product_slider_type_select['label'];

	}

	$wp_customize->add_control( 'flat_commerce_theme_options[product_slider_type_select]', array(
		'active_callback'	=> 'flat_commerce_is_product_slider_active',
		'label'    			=> esc_html__( 'Select Product Slider Type', 'flat-commerce' ),
		'priority'			=> '1.2',
		'section'  			=> 'flat_commerce_product_slider',
		'settings' 			=> 'flat_commerce_theme_options[product_slider_type_select]',
		'type'    			=> 'select',
		'choices'			=> $choices,
	));

	// number of slides
	$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_no_of_tabs]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['product_slider_no_of_tabs'],
		'sanitize_callback' => 'flat_commerce_sanitize_number_range',
	) );

	$flat_commerce_product_slider_tab_options = flat_commerce_product_slider_tab_options();
	$choices = array();

	foreach ( $flat_commerce_product_slider_tab_options as $flat_commerce_product_slider_tab_option ) {

		$choices[$flat_commerce_product_slider_tab_option['value']] = $flat_commerce_product_slider_tab_option['label'];

	}
	$wp_customize->add_control( 'flat_commerce_theme_options[product_slider_no_of_tabs]', array(
		'active_callback' 	=> 'flat_commerce_is_product_category_slider_active',
		'label'    			=> esc_html__( 'Number of Tabs', 'flat-commerce' ),
		'description' 		=> esc_html__( 'Save and refresh the page if number of Tabs is changed ( Max number of Tab is 5 )', 'flat-commerce'),
		'priority'			=> '1.3',
		'section'  			=> 'flat_commerce_product_slider',
		'settings'			=> 'flat_commerce_theme_options[product_slider_no_of_tabs]',
		'type'    			=> 'select',
		'choices'			=> $choices
	) );

	// add Product SLider Banner section
	$wp_customize->add_section( 'flat_commerce_product_slider_banner', array(
		'panel'				=> 'flat_commerce_product_slider_options',
		'priority'      	=> 620,
		'title'				=> esc_html__( 'Product Slider Banner', 'flat-commerce' ),
	) );

	// banner control
	$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_exclusive_banner_control]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['product_slider_exclusive_banner_control'],
		'sanitize_callback'	=> 'flat_commerce_sanitize_checkbox',

	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[product_slider_exclusive_banner_control]' ,array(
		'label'				=> esc_html__( 'Check to disable Banner', 'flat-commerce' ),
		'description'		=> esc_html__( 'Works only when ( Enable slider On ) option is not disabled.', 'flat-commerce'),
		'priority'			=> '10',
		'section'   		=> 'flat_commerce_product_slider_banner',
		'setting'			=> 'flat_commerce_theme_options[product_slider_exclusive_banner_control]',
		'type'				=> 'checkbox',
	) );

	// banner Image
	$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_exclusive_banner]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['product_slider_exclusive_banner'],
		'sanitize_callback'	=> 'flat_commerce_sanitize_image',

	) );

	$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize,
		'flat_commerce_theme_options[product_slider_exclusive_banner]' ,
		array(
        'active_callback'	=> 'flat_commerce_is_product_banner_active',
		'label'				=> esc_html__( 'Upload Exclusive Product Banner', 'flat-commerce' ),
		'priority'			=> '20',
		'section'   		=> 'flat_commerce_product_slider_banner',
		'setting'			=> 'flat_commerce_theme_options[product_slider_exclusive_banner]'
	) ) );


	// Banner Image URL
	$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_exclusive_banner_url]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['product_slider_exclusive_banner_url'],
		'sanitize_callback'	=> 'esc_url',

	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[product_slider_exclusive_banner_url]' ,
		array(
      'active_callback'	=> 'flat_commerce_is_product_banner_active',
		'label'				=> esc_html__( 'Exclusive Product Banner URL', 'flat-commerce' ),
		'priority'			=> '20',
		'section'   		=> 'flat_commerce_product_slider_banner',
		'setting'			=> 'flat_commerce_theme_options[product_slider_exclusive_banner_url]',
		'type'				=> 'url'
	) );

	// banner alt text
	$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_banner_alt_text]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['product_slider_banner_alt_text'],
		'sanitize_callback'	=> 'sanitize_text_field',

	) );

	$wp_customize->add_control(	'flat_commerce_theme_options[product_slider_banner_alt_text]',	array(
		'active_callback'	=> 'flat_commerce_is_product_banner_active',
		'label'				=> esc_html__( 'Alt Text', 'flat-commerce' ),
		'priority'			=> '50',
		'section'   		=> 'flat_commerce_product_slider_banner',
		'setting'			=> 'flat_commerce_theme_options[product_slider_banner_alt_text]',
	) );

	// Product Slider Control Section
	$wp_customize->add_section( 'flat_commerce_product_slider_controls', array(
		'panel'				=> 'flat_commerce_product_slider_options',
		'priority'      	=> 630,
		'title'				=> esc_html__( 'Product Slider Controls', 'flat-commerce' ),
		'description'		=> esc_html__( 'Controls for Product Slider except Demo Slider', 'flat-commerce')
	) );

	// transition effects
	$wp_customize->add_setting( 'flat_commerce_theme_options[product_slide_transition_effect]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['product_slide_transition_effect'],
		'sanitize_callback'	=> 'flat_commerce_sanitize_select',
	) );

	$flat_commerce_product_slide_transition_effects = flat_commerce_featured_slide_transition_effects();
	$choices = array();

	foreach ( $flat_commerce_product_slide_transition_effects as $flat_commerce_product_slide_transition_effect ) {
		$choices[$flat_commerce_product_slide_transition_effect['value']] = $flat_commerce_product_slide_transition_effect['label'];
	}

	$wp_customize->add_control( 'flat_commerce_theme_options[product_slide_transition_effect]' , array(
		'active_callback'	=> 'flat_commerce_is_product_category_slider_active',
		'choices'  			=> $choices,
		'label'				=> esc_html__( 'Transition Effect', 'flat-commerce' ),
		'priority'			=> '2',
		'section'  			=> 'flat_commerce_product_slider_controls',
		'settings' 			=> 'flat_commerce_theme_options[product_slide_transition_effect]',
		'type'	  			=> 'select',
	) );

	// transition delay
	$wp_customize->add_setting( 'flat_commerce_theme_options[product_slide_transition_delay]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['product_slide_transition_delay'],
		'sanitize_callback'	=> 'flat_commerce_sanitize_number_range',
		'validate_callback' => 'flat_commerce_validate_slide_transition_delay'
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[product_slide_transition_delay]' , array(
		'active_callback'	=> 'flat_commerce_is_product_category_slider_active',
		'description'		=> 	esc_html__( 'seconds(s)', 'flat-commerce' ),
    	'label'    			=> esc_html__( 'Transition Delay', 'flat-commerce' ),
		'priority'			=> '2.1.1',
		'section'  			=> 'flat_commerce_product_slider_controls',
		'settings' 			=> 'flat_commerce_theme_options[product_slide_transition_delay]',
		'type'	   			=> 'number',
		'input_attrs' => array(
            'min'   		=> 1,
            'style' 		=> 'width: 60px;'
		),
	) );

	// transition length
	$wp_customize->add_setting( 'flat_commerce_theme_options[product_slide_transition_length]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['product_slide_transition_length'],
		'sanitize_callback'	=> 'flat_commerce_sanitize_number_range',
		'validate_callback' => 'flat_commerce_validate_slide_transition_length'
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[product_slide_transition_length]' , array(
		'active_callback'	=> 'flat_commerce_is_product_category_slider_active',
		'description'		=> esc_html__( 'seconds(s)', 'flat-commerce' ),
    	'label'    			=> esc_html__( 'Transition Length', 'flat-commerce' ),
		'priority'			=> '2.1.2.1',
		'section'  			=> 'flat_commerce_product_slider_controls',
		'settings' 			=> 'flat_commerce_theme_options[product_slide_transition_length]',
		'type'	   			=> 'number',
		'input_attrs' 		=> array(
            'min'   		=> 1,
            'style' 		=> 'width: 60px;'
		),
	) );

	// Tabs options
	$no_of_tabs 			= $options['product_slider_no_of_tabs'];

	for( $i = 1; $i <= $no_of_tabs; $i++ ){

		$wp_customize->add_section( 'flat_commerce_product_slider_'. $i, array(
			'priority'      	=> '640'.$i,
			'title'				=>  esc_html__( 'Tab Content', 'flat-commerce' ).$i,
			'panel'				=> 'flat_commerce_product_slider_options',
		) );

		// tab title
		$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_tab_content_'.$i.']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback' => 'sanitize_term_field',
		) );

		$wp_customize->add_control( new Flat_Commerce_Note_Control( $wp_customize,
			'flat_commerce_theme_options[product_slider_tab_content_'.$i.']', array(
			'active_callback' 	=> 'flat_commerce_is_product_category_slider_active',
			'label'    			=> esc_html__( 'Tab Content ', 'flat-commerce' ).$i,
			'priority'			=> '1.4.'.$i,
			'section'  			=> 'flat_commerce_product_slider_'. $i,
			'settings'			=> 'flat_commerce_theme_options[product_slider_tab_content_'.$i.']',
			'type'    			=> 'description',
		) ) );

		// product category
		$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_category_'.$i.']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback' => 'sanitize_key',
		) );

		$wp_customize->add_control( new Flat_Commerce_Customize_WC_Dropdown_Product_Category( $wp_customize,
			'flat_commerce_theme_options[product_slider_category_'.$i.']', array(
			'active_callback' 	=> 'flat_commerce_is_product_category_slider_active',
			'label'    			=> esc_html__( 'Select Product Category for Tab ', 'flat-commerce' ).$i,
			'priority'			=> '1.5.'.$i,
			'section'  			=> 'flat_commerce_product_slider_'. $i,
			'settings'			=> 'flat_commerce_theme_options[product_slider_category_'.$i.']',
			'type'    			=> 'wc-dropdown-category',
		) ) );


		$flat_commerce_get_product_slider_layouts = flat_commerce_get_product_slider_layout();
		$choices = array();

		foreach ( $flat_commerce_get_product_slider_layouts as $flat_commerce_get_product_slider_layout ) {
			$choices[$flat_commerce_get_product_slider_layout['value']] = $flat_commerce_get_product_slider_layout['label'];
		}
		// products layout option
		$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_layout_option_'.$i.']', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['product_slider_layout_option'],
			'sanitize_callback' => 'flat_commerce_sanitize_select',
		) );

		$wp_customize->add_control(
			'flat_commerce_theme_options[product_slider_layout_option_'.$i.']', array(
			'active_callback' 	=> 'flat_commerce_is_product_category_slider_active',
			'label'    			=> esc_html__( 'Product slider layout', 'flat-commerce' ),
			'description'		=> esc_html__( 'Enter Layout Option From 3 to 12','flat-commerce'),
			'priority'			=> '1.6.'.$i,
			'section'  			=> 'flat_commerce_product_slider_'. $i,
			'settings'			=> 'flat_commerce_theme_options[product_slider_layout_option_'.$i.']',
			'type'    			=> 'select',
			'choices'		=> $choices
		) );

		// number of products
		$wp_customize->add_setting( 'flat_commerce_theme_options[product_slider_no_of_products_for_category_'.$i.']', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['product_slider_no_of_products_for_category'],
			'sanitize_callback' => 'flat_commerce_sanitize_number_range',
			'validate_callback'	=> 'flat_commerce_validate_no_of_products_for_category'
		) );

		$wp_customize->add_control(
			'flat_commerce_theme_options[product_slider_no_of_products_for_category_'.$i.']', array(
			'active_callback' 	=> 'flat_commerce_is_product_category_slider_active',
			'label'    			=> esc_html__( 'Show number of Products for Tab ', 'flat-commerce' ).$i,
			'description'		=> esc_html__( 'Enter number of products to be shown under category tab. Maximum number is 15.','flat-commerce'),
			'priority'			=> '1.7.'.$i,
			'section'  			=> 'flat_commerce_product_slider_'. $i,
			'settings'			=> 'flat_commerce_theme_options[product_slider_no_of_products_for_category_'.$i.']',
			'type'    			=> 'number',
			'input_attrs'		=> array(
				'min'			=> 1,
				'range'		=> 1,
				'max'			=> 15,
	            'style' 		=> 'width: 60px;'),
		) );
	}

// Product Slider End