<?php
/**
 * The template for adding additional theme options in Customizer
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

// Additional Color Scheme (added to Color Scheme section in Theme Customizer)
if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}

//Theme Options
	$wp_customize->add_panel( 'flat_commerce_theme_options', array(
	    'description'    => esc_html__( 'Basic theme Options', 'flat-commerce' ),
	    'capability'     => 'edit_theme_options',
	    'priority'       => 700,
	    'title'    		 => esc_html__( 'Theme Options', 'flat-commerce' ),
	) );

	// Breadcrumb Option
	$wp_customize->add_section( 'flat_commerce_breadcumb_options', array(
		'description'	=> esc_html__( 'Breadcrumbs are a great way of letting your visitors find out where they are on your site with just a glance. You can enable/disable them on homepage and entire site.', 'flat-commerce' ),
		'panel'			=> 'flat_commerce_theme_options',
		'title'    		=> esc_html__( 'Breadcrumb Options', 'flat-commerce' ),
		'priority' 		=> 700,
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[breadcumb_option]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['breadcumb_option'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[breadcumb_option]', array(
		'label'    => esc_html__( 'Check to enable Breadcrumb', 'flat-commerce' ),
		'section'  => 'flat_commerce_breadcumb_options',
		'settings' => 'flat_commerce_theme_options[breadcumb_option]',
		'type'     => 'checkbox',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[breadcumb_onhomepage]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['breadcumb_onhomepage'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox'
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[breadcumb_onhomepage]', array(
		'label'    => esc_html__( 'Check to enable Breadcrumb on Homepage', 'flat-commerce' ),
		'section'  => 'flat_commerce_breadcumb_options',
		'settings' => 'flat_commerce_theme_options[breadcumb_onhomepage]',
		'type'     => 'checkbox',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[breadcumb_seperator]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['breadcumb_seperator'],
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[breadcumb_seperator]', array(
		'input_attrs' => array(
        		'style' => 'width: 40px;'
    		),
    	'label'    	=> esc_html__( 'Separator between Breadcrumbs', 'flat-commerce' ),
		'section' 	=> 'flat_commerce_breadcumb_options',
		'settings' 	=> 'flat_commerce_theme_options[breadcumb_seperator]',
		'type'     	=> 'text'
		)
	);
   	// Breadcrumb Option End

	if ( version_compare( $GLOBALS['wp_version'], '4.7', '<' ) ) {
	// Custom CSS Option
	$wp_customize->add_section( 'flat_commerce_custom_css', array(
		'description'	=> esc_html__( 'Custom/Inline CSS', 'flat-commerce'),
		'panel'  		=> 'flat_commerce_theme_options',
		'priority' 		=> 203,
		'title'    		=> esc_html__( 'Custom CSS Options', 'flat-commerce' ),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[custom_css]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['custom_css'],
		'sanitize_callback' => 'flat_commerce_sanitize_custom_css',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[custom_css]', array(
			'label'		=> esc_html__( 'Enter Custom CSS', 'flat-commerce' ),
	        'priority'	=> 1,
			'section'   => 'flat_commerce_custom_css',
	        'settings'  => 'flat_commerce_theme_options[custom_css]',
			'type'		=> 'textarea',
	) );
   	// Custom CSS End
	}

   	// Excerpt Options
	$wp_customize->add_section( 'flat_commerce_excerpt_options', array(
		'panel'  	=> 'flat_commerce_theme_options',
		'priority' 	=> 204,
		'title'    	=> esc_html__( 'Excerpt Options', 'flat-commerce' ),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[excerpt_length]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['excerpt_length'],
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[excerpt_length]', array(
		'description' => esc_html__('Excerpt length. Default is 55 words', 'flat-commerce'),
		'input_attrs' => array(
            'min'   => 10,
            'max'   => 200,
            'step'  => 5,
            'style' => 'width: 60px;'
            ),
        'label'    => esc_html__( 'Excerpt Length (words)', 'flat-commerce' ),
		'section'  => 'flat_commerce_excerpt_options',
		'settings' => 'flat_commerce_theme_options[excerpt_length]',
		'type'	   => 'number',
		)
	);

	$wp_customize->add_setting( 'flat_commerce_theme_options[excerpt_more_text]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['excerpt_more_text'],
		'sanitize_callback'	=> 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[excerpt_more_text]', array(
		'label'    => esc_html__( 'Read More Text', 'flat-commerce' ),
		'section'  => 'flat_commerce_excerpt_options',
		'settings' => 'flat_commerce_theme_options[excerpt_more_text]',
		'type'	   => 'text',
	) );
	// Excerpt Options End

	// Font Family Options
	$wp_customize->add_section( 'flat_commerce_font_family', array(
		'panel'  => 'flat_commerce_theme_options',
		'priority'	=> 206,
		'title'    	=> esc_html__( 'Font Family Options', 'flat-commerce' ),
	) );

	$avaliable_fonts = flat_commerce_avaliable_fonts();

	$choices = array();

	foreach ( $avaliable_fonts as $avaliable_font ) {
		$choices[ $avaliable_font[ 'value' ] ] = str_replace( '"', '', $avaliable_font[ 'label' ] );
	}

	$font_family_options	=	array(
										'title_font' 		=> esc_html__( 'Site Title Font Family', 'flat-commerce' ),
										'body_font' 		=> esc_html__( 'Default Font Family', 'flat-commerce' ),
										'tagline_font' 		=> esc_html__( 'Site Tagline Font Family', 'flat-commerce' ),
										'content_title_font'=> esc_html__( 'Content Title Font Family', 'flat-commerce' ),
										'content_font' 		=> esc_html__( 'Content Body Font Family', 'flat-commerce' ),
										'headings_font' 	=> esc_html__( 'Headings Tags from h1 to h6 Font Family', 'flat-commerce' )
									);

	foreach ( $font_family_options as $key => $font_family_option ) {
		$wp_customize->add_setting( 'flat_commerce_theme_options['. $key . ']', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults[ $key ],
			'sanitize_callback' => 'sanitize_key',
		) );

		$wp_customize->add_control( 'flat_commerce_theme_options['. $key . ']', array(
			'choices'  => $choices,
			'label'    => $font_family_option,
			'section'  => 'flat_commerce_font_family',
			'settings' => 'flat_commerce_theme_options['. $key . ']',
			'type'	   => 'select',
		) );
	}

	$wp_customize->add_setting( 'flat_commerce_theme_options[reset_typography]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['reset_typography'],
		'sanitize_callback' => 'flat_commerce_reset_typography'
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[reset_typography]', array(
		'label'		=> esc_html__( 'Check to reset fonts', 'flat-commerce' ),
		'section'	=> 'flat_commerce_font_family',
		'settings'	=> 'flat_commerce_theme_options[reset_typography]',
		'type'		=> 'checkbox',
	) );
	// Font Family Options End

	// Footer Editor Options
	$wp_customize->add_section( 'flat_commerce_footer_options', array(
		'description'	=> esc_html__( 'You can either add html or plain text', 'flat-commerce'),
		'panel'  => 'flat_commerce_theme_options',
		'priority' 		=> 207,
		'title'    		=> esc_html__( 'Footer Editor Options', 'flat-commerce' ),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[footer_content]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['footer_content'],
		'sanitize_callback'	=> 'flat_commerce_sanitize_footer_code',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[footer_content]', array(
			'description' 	=> esc_html__( 'You can add custom shortcodes, which will be automatically inserted into your theme. Some shorcodes: [the-year] and [site-link] for current year and site link respectively.', 'flat-commerce' ),
			'label'		=> esc_html__( 'Footer Left Content', 'flat-commerce' ),
	        'priority'	=> 1,
			'section'   => 'flat_commerce_footer_options',
	        'settings'  => 'flat_commerce_theme_options[footer_content]',
			'type'		=> 'textarea',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[reset_footer_content]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['reset_footer_content'],
		'sanitize_callback' => 'flat_commerce_sanitize_footer_content'
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[reset_footer_content]', array(
		'label'		=> esc_html__( 'Check to reset Footer Content', 'flat-commerce' ),
		'priority'	=> 3,
		'settings'	=> 'flat_commerce_theme_options[reset_footer_content]',
		'section'	=> 'flat_commerce_footer_options',
		'type'		=> 'checkbox',
	) );
	// Footer Options End


	//Homepage / Static Frontpage Options
	$wp_customize->add_section( 'flat_commerce_homepage_options', array(
		'description'	=> esc_html__( 'Go to ( Settings->Reading->Blog pages show at most) to change no of blog posts visible', 'flat-commerce' ),
		'panel'			=> 'flat_commerce_theme_options',
		'priority' 		=> 209,
		'title'   	 	=> esc_html__( 'Homepage / Static Frontpage Options', 'flat-commerce' ),
	) );

	 // Blog heading
    $wp_customize->add_setting( 'flat_commerce_theme_options[latest_blog_heading]', array(
        'capability'        => 'edit_theme_options',
        'default'           => $defaults['latest_blog_heading'],
        'transport'			=> 'postMessage',
        'sanitize_callback' => 'sanitize_text_field',
    ) );

    // Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'flat_commerce_theme_options[latest_blog_heading]', array(
			'selector'            => '#blog h2.entry-title',
			'render_callback'     => 'flat_commerce_customize_partial_latest_blog_heading',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
		) );
	}

    $wp_customize->add_control( 'flat_commerce_theme_options[latest_blog_heading]' , array(
        'label'         => esc_html__( 'Heading', 'flat-commerce' ),
        'priority'      => '5',
        'section'       => 'flat_commerce_homepage_options',
        'settings'      => 'flat_commerce_theme_options[latest_blog_heading]',
        )
    );

	$wp_customize->add_setting( 'flat_commerce_theme_options[front_page_category]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['front_page_category'],
		'sanitize_callback'	=> 'flat_commerce_sanitize_category_list',
	) );

	$wp_customize->add_control( new Flat_Commerce_Post_Dropdown_Categories_Control( $wp_customize, 'flat_commerce_theme_options[front_page_category]', array(
        'label'   	=> esc_html__( 'Select Categories', 'flat-commerce' ),
        'name'	 	=> 'flat_commerce_theme_options[front_page_category]',
		'priority'	=> '6',
        'section'  	=> 'flat_commerce_homepage_options',
        'settings' 	=> 'flat_commerce_theme_options[front_page_category]',
        'type'     	=> 'post-dropdown-categories',
    ) ) );

	 // Layout

	 $wp_customize->add_setting( 'flat_commerce_theme_options[latest_blog_layout]', array(
	     'capability'        => 'edit_theme_options',
	     'default'           => $defaults['latest_blog_layout'],
	     'sanitize_callback' => 'flat_commerce_sanitize_number_range',
	     'validate_callback' => 'flat_commerce_validate_latest_blog_layout'
	 ) );

	 $wp_customize->add_control( 'flat_commerce_theme_options[latest_blog_layout]', array(
	     'label'     => esc_html__( 'Posts Layout', 'flat-commerce' ),
	     'description' => esc_html__('Layout option for posts. Maximum number of layout is 3.', 'flat-commerce'),
	     'priority'  => 30,
	     'section'   => 'flat_commerce_homepage_options',
	     'settings'  => 'flat_commerce_theme_options[latest_blog_layout]',
	     'type'      => 'number',
	     'input_attrs' => array(
	         'style' => 'width: 40px;',
	         'max' => 3,
	         'min' => 1,
	         )
	 ) );

	 // Number of products
	 $wp_customize->add_setting( 'flat_commerce_theme_options[latest_blog_posts_number]', array(
	     'capability'        => 'edit_theme_options',
	     'default'           => $defaults['latest_blog_posts_number'],
	     'sanitize_callback' => 'flat_commerce_sanitize_number_range',
	     'validate_callback' => 'flat_commerce_latest_blog_posts_number'
	 ) );

	 $wp_customize->add_control( 'flat_commerce_theme_options[latest_blog_posts_number]', array(
	     'label'     => esc_html__( 'Number of Posts', 'flat-commerce' ),
	     'priority'  => 40,
	     'section'   => 'flat_commerce_homepage_options',
	     'settings'  => 'flat_commerce_theme_options[latest_blog_posts_number]',
	     'type'      => 'number',
	     'input_attrs' => array(
	         'style' => 'width: 40px;',
	         'max' => 6,
	         'min' => 1,
	         )
	 ) );

	//Homepage / Static Frontpage Settings End

	// Layout Options
	$wp_customize->add_section( 'flat_commerce_layout', array(
		'capability'=> 'edit_theme_options',
		'panel'		=> 'flat_commerce_theme_options',
		'priority'	=> 211,
		'title'		=> esc_html__( 'Layout Options', 'flat-commerce' ),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[theme_layout]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['theme_layout'],
		'sanitize_callback' => 'sanitize_key',
	) );

	$layouts = flat_commerce_layouts();
	$choices = array();
	foreach ( $layouts as $layout ) {
		$choices[ $layout['value'] ] = $layout['label'];
	}

	$wp_customize->add_control( 'flat_commerce_theme_options[theme_layout]', array(
		'choices'	=> $choices,
		'label'		=> esc_html__( 'Default Layout', 'flat-commerce' ),
		'section'	=> 'flat_commerce_layout',
		'settings'   => 'flat_commerce_theme_options[theme_layout]',
		'type'		=> 'select',
	) );

	if ( class_exists( 'WooCommerce' ) ) {
		$wp_customize->add_setting( 'flat_commerce_theme_options[woocommerce_layout]', array(
			'capability'		=> 'edit_theme_options',
			'default'			=> $defaults['woocommerce_layout'],
			'sanitize_callback' => 'sanitize_key',
		) );

		$wp_customize->add_control( 'flat_commerce_theme_options[woocommerce_layout]', array(
			'choices'	=> $choices,
			'label'		=> esc_html__( 'Woocommerce Layout', 'flat-commerce' ),
			'section'	=> 'flat_commerce_layout',
			'settings'   => 'flat_commerce_theme_options[woocommerce_layout]',
			'type'		=> 'select',
		) );
	}

	$wp_customize->add_setting( 'flat_commerce_theme_options[content_layout]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['content_layout'],
		'sanitize_callback' => 'sanitize_key',
	) );

	$layouts = flat_commerce_get_archive_content_layout();
	$choices = array();
	foreach ( $layouts as $layout ) {
		$choices[ $layout['value'] ] = $layout['label'];
	}

	$wp_customize->add_control( 'flat_commerce_theme_options[content_layout]', array(
		'choices'   => $choices,
		'label'		=> esc_html__( 'Archive Content Layout', 'flat-commerce' ),
		'section'   => 'flat_commerce_layout',
		'settings'  => 'flat_commerce_theme_options[content_layout]',
		'type'      => 'select',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[single_post_image_layout]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['single_post_image_layout'],
		'sanitize_callback' => 'sanitize_key',
	) );


	$single_post_image_layouts = flat_commerce_single_post_image_layout_options();
	$choices = array();
	foreach ( $single_post_image_layouts as $single_post_image_layout ) {
		$choices[$single_post_image_layout['value']] = $single_post_image_layout['label'];
	}

	$wp_customize->add_control( 'flat_commerce_theme_options[single_post_image_layout]', array(
			'label'		=> esc_html__( 'Single Page/Post Image Layout ', 'flat-commerce' ),
			'section'   => 'flat_commerce_layout',
	        'settings'  => 'flat_commerce_theme_options[single_post_image_layout]',
	        'type'	  	=> 'select',
			'choices'  	=> $choices,
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[enable_sticky_menu]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['enable_sticky_menu'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[enable_sticky_menu]', array(
			'label'		=> esc_html__( 'Enable Sticky Menu ', 'flat-commerce' ),
			'section'   => 'flat_commerce_layout',
	        'settings'  => 'flat_commerce_theme_options[enable_sticky_menu]',
	        'type'	  	=> 'checkbox',
	) );
   	// Layout Options End

	// Pagination Options
	$pagination_type	= $options['pagination_type'];

	$flat_commerce_navigation_description = sprintf( __( 'Numeric Option requires <a target="_blank" href="%1$s">WP-PageNavi Plugin</a>.<br/>Infinite Scroll Options requires <a target="_blank" href="%2$s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'flat-commerce' ), esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ), esc_url( 'https://wordpress.org/plugins/jetpack/' ) );

	/**
	 * Check if navigation type is Jetpack Infinite Scroll and if it is enabled
	 */
	if ( ( 'infinite-scroll-click' == $pagination_type || 'infinite-scroll-scroll' == $pagination_type ) ) {
		if ( ! (class_exists( 'Jetpack' ) && Jetpack::is_module_active( 'infinite-scroll' ) ) ) {
			$flat_commerce_navigation_description = sprintf( __( 'Infinite Scroll Options requires <a target="_blank" href="%s">JetPack Plugin</a> with Infinite Scroll module Enabled.', 'flat-commerce' ), esc_url( 'https://wordpress.org/plugins/jetpack/' ) );
		}
		else {
			$flat_commerce_navigation_description = '';
		}
	}
	/**
	* Check if navigation type is numeric and if Wp-PageNavi Plugin is enabled
	*/
	else if ( 'numeric' == $pagination_type ) {
		if ( !function_exists( 'wp_pagenavi' ) ) {
			$flat_commerce_navigation_description = sprintf( __( 'Numeric Option requires <a target="_blank" href="%s">WP-PageNavi Plugin</a>.', 'flat-commerce' ), esc_url( 'https://wordpress.org/plugins/wp-pagenavi' ) );
		}
		else {
			$flat_commerce_navigation_description = '';
		}
    }

	$wp_customize->add_section( 'flat_commerce_pagination_options', array(
		'description'	=> $flat_commerce_navigation_description,
		'panel'  		=> 'flat_commerce_theme_options',
		'priority'		=> 212,
		'title'    		=> esc_html__( 'Pagination Options', 'flat-commerce' ),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[pagination_type]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['pagination_type'],
		'sanitize_callback' => 'sanitize_key',
	) );

	$pagination_types = flat_commerce_get_pagination_types();
	$choices = array();
	foreach ( $pagination_types as $pagination_type ) {
		$choices[$pagination_type['value']] = $pagination_type['label'];
	}

	$wp_customize->add_control( 'flat_commerce_theme_options[pagination_type]', array(
		'choices'  => $choices,
		'label'    => esc_html__( 'Pagination type', 'flat-commerce' ),
		'section'  => 'flat_commerce_pagination_options',
		'settings' => 'flat_commerce_theme_options[pagination_type]',
		'type'	   => 'select',
	) );
	// Pagination Options End

	// Scrollup
	$wp_customize->add_section( 'flat_commerce_scrollup', array(
		'panel'    => 'flat_commerce_theme_options',
		'priority' => 215,
		'title'    => esc_html__( 'Scrollup Options', 'flat-commerce' ),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[disable_scrollup]', array(
		'capability'		=> 'edit_theme_options',
        'default'			=> $defaults['disable_scrollup'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[disable_scrollup]', array(
		'label'		=> esc_html__( 'Check to disable Scroll Up', 'flat-commerce' ),
		'section'   => 'flat_commerce_scrollup',
        'settings'  => 'flat_commerce_theme_options[disable_scrollup]',
		'type'		=> 'checkbox',
	) );
	// Scrollup End

	// Single Post Navigation
	$wp_customize->add_section( 'flat_commerce_single_post_navigation', array(
		'panel'  => 'flat_commerce_theme_options',
		'priority' => 217,
		'title'    => esc_html__( 'Single Post Navigation', 'flat-commerce' ),
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[disable_single_post_navigation]', array(
		'capability'		=> 'edit_theme_options',
        'default'			=> $defaults['disable_single_post_navigation'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[disable_single_post_navigation]', array(
		'label'		=> esc_html__( 'Check to disable Single Post Navigation', 'flat-commerce' ),
		'section'   => 'flat_commerce_single_post_navigation',
        'settings'  => 'flat_commerce_theme_options[disable_single_post_navigation]',
		'type'		=> 'checkbox',
	) );
	// Single Post Navigation End

	// Update Notifier
	$wp_customize->add_section( 'flat_commerce_update_notifier', array(
		'title'    => esc_html__( 'Update Notifier', 'flat-commerce' ),
		'priority' => 217,
		'panel'    => 'flat_commerce_theme_options',
	) );

	$wp_customize->add_setting( 'flat_commerce_theme_options[update_notifier]', array(
		'capability'		=> 'edit_theme_options',
		'default'			=> $defaults['update_notifier'],
		'sanitize_callback' => 'flat_commerce_sanitize_checkbox',
	) );

	$wp_customize->add_control( 'flat_commerce_theme_options[update_notifier]', array(
		'label'		=> esc_html__( 'Check to disable update notifications', 'flat-commerce' ),
		'section'   => 'flat_commerce_update_notifier',
        'settings'  => 'flat_commerce_theme_options[update_notifier]',
		'type'		=> 'checkbox',
	) );
	// Update Notifier End
//Theme Option End