<?php
/**
 * The template for displaying the Featured Content
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
    header( 'Status: 403 Forbidden' );
    header( 'HTTP/1.1 403 Forbidden' );
    exit();
}


if( !function_exists( 'flat_commerce_featured_product_display' ) ) :
/**
* Add Featured content.
*
* @uses action hook flat_commerce_before_content.
*
* @since Flat Commerce Pro 1.0
*/
function flat_commerce_featured_product_display() {
    //flat_commerce_flush_transients();
    global $post, $wp_query;

    // get data value from options
    $options        = flat_commerce_get_theme_options();
    $enablecontent  = $options['featured_product_content_option'];
    $contentselect  = $options['featured_product_content_type'];

    // Front page displays in Reading Settings
    $page_on_front  = get_option('page_on_front') ;

    // Get Page ID outside Loop
    $page_id = $wp_query->get_queried_object_id();
    if ( $enablecontent == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enablecontent == 'homepage' ) ) {
            if ( ( ! $flat_commerce_featured_product = get_transient( 'flat_commerce_featured_product' ) ) ) {
                $layouts     = $options ['featured_product_content_layout'];
                $headline    = $options ['featured_product_content_headline'];

                $featured_product_content_subheadline_selected = $options['featured_product_content_subheadline'];

                if ( $featured_product_content_subheadline_selected == 'text' && !empty( $options ['featured_product_content_subheadline_text'] )) {
                    $subheadline_txt = $options ['featured_product_content_subheadline_text'];
                 } elseif ( $featured_product_content_subheadline_selected == 'image' && !empty( $options ['featured_product_content_subheadline_image'] ) ) {

                    $image_attch_id = (int)$options ['featured_product_content_subheadline_image'];
                    $subheadline_img = wp_get_attachment_image_src( $image_attch_id, 'flat-commerce-featured-product-subheadline' );
                    $subheadline_img = $subheadline_img[0];
                 }

                echo '<!-- refreshing cache -->';

                if ( !empty( $layouts ) ) {
                    $classes = $layouts;
                }

                if ( $contentselect == 'demo-featured-content' ) {
                    $classes        .= ' demo-featured-content' ;
                }

                $featured_product_position = $options [ 'featured_product_content_position' ];

                if ( '0' == $featured_product_position ) {
                    $classes .= ' border-top' ;
                }

                $flat_commerce_featured_product ='
                    <section id="featured">
                        <div class="black-overlay overlay-1"></div>
                        <div class="white-overlay overlay-2"></div>
                        <div class="container">
                            <div class="featured-wrapper">
                                <div class="row">
                                    <div class="col col-1-of-1">
                                        <header class="entry-header screen-reader-text">
                                            <h2 class="entry-title">'.esc_html__( 'Featured Section', 'flat-commerce' ).'</h2>
                                        </header><!-- .entry-header -->
                                    </div><!-- .col -->';
                                $flat_commerce_featured_product .='<div class="col col-5-of-12 col-push-1-of-12">
                                                                        <div class="v-center featured-time">';
                                if ( !empty( $headline ) ) {
                                    $flat_commerce_featured_product .='<span class="entry-title">'. $headline .'</span>';
                                }
                                $flat_commerce_featured_product .='<span class="featured-tag">';
                                if ( !empty( $subheadline_img ) ) {
                                    $flat_commerce_featured_product .= '<img src="'.esc_url( $subheadline_img ).'" />';
                                } elseif ( !empty( $subheadline_txt )) {
                                    $flat_commerce_featured_product .= $subheadline_txt;
                                }
                                $flat_commerce_featured_product .='</span>';
                                $flat_commerce_featured_product .='</div>
                                                                </div><!-- .col -->';

                                // Select content
                                if ( $contentselect == 'demo-featured-content' && function_exists( 'flat_commerce_demo_content' ) ) {
                                    $flat_commerce_featured_product .= flat_commerce_demo_content( $options );
                                }
                                else if ( $contentselect == 'featured-post-content' && function_exists( 'flat_commerce_post_content' ) ) {
                                    $flat_commerce_featured_product .= flat_commerce_post_content( $options );
                                }
                                elseif ( $contentselect == 'featured-page-content' && function_exists( 'flat_commerce_page_content' ) ) {
                                    $flat_commerce_featured_product .= flat_commerce_page_content( $options );
                                }
                                elseif ( $contentselect == 'featured-category-content' && function_exists( 'flat_commerce_category_content' ) ) {
                                    $flat_commerce_featured_product .= flat_commerce_category_content( $options );
                                }
                                elseif ( $contentselect == 'featured-image-content' && function_exists( 'flat_commerce_image_content' ) ) {
                                    $flat_commerce_featured_product .= flat_commerce_image_content( $options );
                                }
                                elseif ( $contentselect == 'featured-product-content' && function_exists( 'flat_commerce_product_content' ) ) {
                                    $flat_commerce_featured_product .= flat_commerce_product_content( $options );
                                }

                $flat_commerce_featured_product .='
                             </div><!-- .row -->
                        </div><!-- .featured-wrapper -->
                    </div><!-- .container -->
                </section><!-- #featured -->';
                set_transient( 'flat_commerce_featured_product', $flat_commerce_featured_product, 86940 );
            }
            echo $flat_commerce_featured_product;
        }
    }
endif;

if ( ! function_exists( 'flat_commerce_featured_product_display_position' ) ) :
/**
 * Homepage Featured Content Position
 *
 * @action flat_commerce_after_secondary
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_featured_product_display_position() {
    // Getting data from Theme Options
    $options        = flat_commerce_get_theme_options();

    $featured_product_position = $options [ 'featured_product_content_position' ];
    if ( $featured_product_position ) {
        add_action( 'flat_commerce_after_content', 'flat_commerce_featured_product_display', 60 );
    } else {
        add_action( 'flat_commerce_before_content', 'flat_commerce_featured_product_display', 70 );
    }

}
endif; // flat_commerce_featured_product_display_position
add_action( 'flat_commerce_before_content', 'flat_commerce_featured_product_display_position' );


if ( ! function_exists( 'flat_commerce_demo_content' ) ) :
/**
 * This function to display featured posts content
 *
 * @get the data value from customizer options
 *
 * @since Flat Commerce Pro 1.0
 *
 */
function flat_commerce_demo_content( $options ) {
    $flat_commerce_demo_content = '
        <div class="col col-4-of-12  col-push-1-of-12">
            <div class="row">
                <div class="col col-1-of-2">
                    <div class="product-item product-hover">
                        <img src="'.get_template_directory_uri().'/images/gallery/featured1.jpg" width="200" height="200" alt="'. esc_attr( 'featured-product-1','flat-commerce' ) .'"/>
                        <div class="mask">
                            <div class="v-center">
                                <div class="name-of-product">
                                    '. esc_html__( 'Top Ulla coat','flat-commerce' ) .'
                                </div>
                                <a href="#" class="add-to-chart">'. esc_html__( 'View Details','flat-commerce' ) .'</a>
                            </div>
                        </div>  <!-- .mask -->
                    </div>  <!-- .product-item -->
                </div><!-- .col -->
                <div class="col col-1-of-2">

                    <div class="product-item product-hover">
                        <img src="'.get_template_directory_uri().'/images/gallery/featured2.jpg" alt="'. esc_attr( 'featured-product-2','flat-commerce' ) .'" width="200" height="200"/>
                        <div class="mask">
                            <div class="v-center">
                                <div class="name-of-product">
                                    '. esc_html__( 'Top Ulla coat','flat-commerce' ) .'
                                </div>
                                <a href="#" class="add-to-chart">'. esc_html__( 'View Details','flat-commerce' ) .'</a>
                            </div>
                        </div><!-- .mask -->
                    </div>  <!-- .product-item -->
                </div><!-- .col -->
                <div class="col col-1-of-2">
                    <div class="product-item product-hover">
                        <img src="'.get_template_directory_uri().'/images/gallery/featured3.jpg" alt="'. esc_attr( 'featured-product-3','flat-commerce' ) .'" width="200" height="200"/>
                        <div class="mask">
                            <div class="v-center">
                                <div class="name-of-product">
                                    '. esc_html__( 'Top Ulla coat','flat-commerce' ) .'
                                </div>
                                <a href="#" class="add-to-chart">'. esc_html__( 'View Details','flat-commerce' ) .'</a>
                            </div>
                        </div>  <!-- .mask -->
                    </div>  <!-- .product-item -->
                </div><!-- .col -->
                <div class="col col-1-of-2">
                    <div class="product-item product-hover">
                        <img src="'.get_template_directory_uri().'/images/gallery/featured4.jpg" alt="'. esc_attr( 'featured-product-4','flat-commerce' ) .'" width="200" height="200"/>
                        <div class="mask">
                            <div class="v-center">
                                <div class="name-of-product">
                                    '. esc_html__( 'Top Ulla coat','flat-commerce' ) .'
                                </div>
                                <a href="#" class="add-to-chart">'. esc_html__( 'View Details','flat-commerce' ) .'</a>
                            </div>

                        </div>
                    </div> <!-- .product-item -->
                </div><!-- .col -->
            </div><!-- .row -->
        </div><!-- .col -->';

        return $flat_commerce_demo_content;
    }

endif; // flat_commerce_demo_content


if ( ! function_exists( 'flat_commerce_product_content' ) ) :
/**
 * This function to display featured posts content
 *
 * @param $options: flat_commerce_theme_options from customizer
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_product_content( $options ) {
    global $post;

    $quantity       = $options [ 'featured_product_content_number' ];

    $number_of_post = 0;        // for number of posts

    $post_list      = array();  // list of valid post ids

    $layouts     = $options ['featured_product_content_layout'];

    // $show_content    = isset( $options['featured_product_content_show'] ) ? $options['featured_product_content_show'] : 'excerpt';

    $flat_commerce_product_content = '<div class="col col-4-of-12  col-push-1-of-12">
                                        <div class="row">';

    //Get valid number of posts
    for( $i = 1; $i <= $quantity; $i++ ){
        if( isset ( $options['featured_product_content_product_' . $i] ) && $options['featured_product_content_product_' . $i] > 0 ){
            $number_of_post++;

            $post_list  =   array_merge( $post_list, array( $options['featured_product_content_product_' . $i] ) );
        }

    }
    if ( !empty( $post_list ) && $number_of_post > 0 ) {
        $get_featured_posts = new WP_Query( array(
                    'post_type'           => 'product',
                    'posts_per_page'      => $number_of_post,
                    'post__in'            => $post_list,
                    'orderby'             => 'post__in',
                    'ignore_sticky_posts' => 1 // ignore sticky posts
                ));

        $i=0;
        while ( $get_featured_posts->have_posts()) : $get_featured_posts->the_post(); $i++;
            $title_attribute = the_title_attribute( array( 'echo' => false ) );
            // $excerpt = get_the_excerpt();
            $flat_commerce_product_content .= '
                            <div class="col col-1-of-'.$layouts.'">
                                <div class="product-item product-hover">';
                if ( has_post_thumbnail() ) {
                    $flat_commerce_product_content .= get_the_post_thumbnail( $post->ID, 'flat-commerce-featured-product', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ) ) );
                }
                else {
                    $flat_commerce_first_image = wc_placeholder_img( 'flat-commerce-featured-product' );;

                    if ( '' != $flat_commerce_first_image ) {
                        $flat_commerce_product_content .= $flat_commerce_first_image;
                    }
                }

                $flat_commerce_product_content .= '
                    <div class="mask">
                        <div class="v-center">
                            <div class="name-of-product">'.$title_attribute.'</div>';
                            if ( !$options['featured_product_content_url_option'] ) {
                                $flat_commerce_product_content .= '<a href="'.esc_url( get_permalink() ).'" class="add-to-chart">'. esc_html__( 'View Details','flat-commerce' ) .'</a>';
                            }

                $flat_commerce_product_content .=
                        '</div>
                    </div>  <!-- .mask -->';
                    $flat_commerce_product_content .= '
                                </div>  <!-- .product-item -->
                            </div><!-- .col -->';
        endwhile;
        $flat_commerce_product_content .= '
            </div><!-- .row -->
        </div><!-- .col -->';
        wp_reset_query();
    }
    return $flat_commerce_product_content;
}
endif; // flat_commerce_product_content

if ( ! function_exists( 'flat_commerce_post_content' ) ) :
/**
 * This function to display featured posts content
 *
 * @param $options: flat_commerce_theme_options from customizer
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_post_content( $options ) {
    global $post;

    $quantity       = $options [ 'featured_product_content_number' ];

    $number_of_post = 0;        // for number of posts

    $post_list      = array();  // list of valid post ids

    $layouts     = $options ['featured_product_content_layout'];

    // $show_content    = isset( $options['featured_product_content_show'] ) ? $options['featured_product_content_show'] : 'excerpt';

    $flat_commerce_post_content = '<div class="col col-4-of-12  col-push-1-of-12">
                                        <div class="row">';

    //Get valid number of posts
    for( $i = 1; $i <= $quantity; $i++ ){
        if( isset ( $options['featured_product_content_post_' . $i] ) && $options['featured_product_content_post_' . $i] > 0 ){
            $number_of_post++;

            $post_list  =   array_merge( $post_list, array( $options['featured_product_content_post_' . $i] ) );
        }

    }
    if ( !empty( $post_list ) && $number_of_post > 0 ) {
        $get_featured_posts = new WP_Query( array(
                    'posts_per_page' => $number_of_post,
                    'post__in'       => $post_list,
                    'orderby'        => 'post__in',
                    'ignore_sticky_posts' => 1 // ignore sticky posts
                ));

        $i=0;
        while ( $get_featured_posts->have_posts()) : $get_featured_posts->the_post(); $i++;
            $title_attribute = the_title_attribute( array( 'echo' => false ) );
            // $excerpt = get_the_excerpt();
            $flat_commerce_post_content .= '
                            <div class="col col-1-of-'.$layouts.'">
                                <div class="product-item product-hover">';
                if ( has_post_thumbnail() ) {
                    $flat_commerce_post_content .= get_the_post_thumbnail( $post->ID, 'flat-commerce-featured-product', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ) ) );
                }
                else {
                    $flat_commerce_first_image = wc_placeholder_img( 'flat-commerce-featured-product' );;

                    if ( '' != $flat_commerce_first_image ) {
                        $flat_commerce_post_content .= $flat_commerce_first_image;
                    }
                }

                $flat_commerce_post_content .= '
                    <div class="mask">
                        <div class="v-center">
                            <div class="name-of-product">'.$title_attribute.'</div>';
                            if ( !$options['featured_product_content_url_option'] ) {
                                $flat_commerce_post_content .= '<a href="'.esc_url( get_permalink() ).'" class="add-to-chart">'. esc_html__( 'View Details','flat-commerce' ) .'</a>';
                            }

                $flat_commerce_post_content .=
                        '</div>
                    </div>  <!-- .mask -->';
                    $flat_commerce_post_content .= '
                                </div>  <!-- .product-item -->
                            </div><!-- .col -->';
        endwhile;
        $flat_commerce_post_content .= '
            </div><!-- .row -->
        </div><!-- .col -->';
        wp_reset_query();
    }
    return $flat_commerce_post_content;
}
endif; // flat_commerce_post_content


if ( ! function_exists( 'flat_commerce_page_content' ) ) :
/**
 * This function to display featured page content
 *
 * @param $options: flat_commerce_theme_options from customizer
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_page_content( $options ) {
    global $post;

    $layouts     = $options ['featured_product_content_layout'];

    $quantity       = $options [ 'featured_product_content_number' ];

    // $more_link_text  = $options['excerpt_more_text'];

    // $show_content    = isset( $options['featured_product_content_show'] ) ? $options['featured_product_content_show'] : 'excerpt';

    $number_of_page = 0;        // for number of pages

    $page_list      = array();  // list of valid pages ids

    $flat_commerce_page_content = '<div class="col col-4-of-12  col-push-1-of-12">
                                        <div class="row">';

    //Get valid pages
    for( $i = 1; $i <= $quantity; $i++ ){
        if( isset ( $options['featured_product_content_page_' . $i] ) && $options['featured_product_content_page_' . $i] > 0 ){
            $number_of_page++;

            $page_list  =   array_merge( $page_list, array( $options['featured_product_content_page_' . $i] ) );
        }

    }
    if ( !empty( $page_list ) && $number_of_page > 0 ) {
        $get_featured_posts = new WP_Query( array(
                    'posts_per_page'        => $number_of_page,
                    'post__in'              => $page_list,
                    'orderby'               => 'post__in',
                    'post_type'             => 'page',
                ));

        $i=0;
        while ( $get_featured_posts->have_posts()) : $get_featured_posts->the_post(); $i++;
            $title_attribute = the_title_attribute( array( 'echo' => false ) );

            $excerpt = get_the_excerpt();

            $flat_commerce_page_content .= '
                <div class="col col-1-of-'.$layouts.'">
                    <div class="product-item product-hover">';
                if ( has_post_thumbnail() ) {
                    $flat_commerce_page_content .= get_the_post_thumbnail( $post->ID, 'flat-commerce-featured-product', array( 'title' => esc_attr( $title_attribute ), 'alt' => esc_attr( $title_attribute ) ) );
                }
                else {
                    $flat_commerce_first_image = wc_placeholder_img( 'flat-commerce-featured-product' );;

                    if ( '' != $flat_commerce_first_image ) {
                        $flat_commerce_page_content .= $flat_commerce_first_image;
                    }
                }

                $flat_commerce_page_content .= '
                    <div class="mask">
                        <div class="v-center">
                            <div class="name-of-product">'.$title_attribute.'</div>';
                            if ( !$options['featured_product_content_url_option'] ) {
                                $flat_commerce_page_content .= '<a href="'.esc_url( get_permalink() ).'" class="add-to-chart">'. esc_html__( 'View Details','flat-commerce' ) .'</a>';
                            }

                $flat_commerce_page_content .=
                            '</div>
                        </div>  <!-- .mask -->
                    </div>  <!-- .product-item -->
                </div><!-- .col -->';
        endwhile;
        $flat_commerce_page_content .= '
            </div><!-- .row -->
        </div><!-- .col -->';
        wp_reset_query();
    }
    return $flat_commerce_page_content;
}
endif; // flat_commerce_page_content


if ( ! function_exists( 'flat_commerce_category_content' ) ) :
/**
 * This function to display featured category content
 *
 * @param $options: flat_commerce_theme_options from customizer
 *
 * @since Flat Commerce Pro 1.0
 */

function flat_commerce_category_content( $options ) {
    global $post;

    $quantity = $options [ 'featured_product_content_number' ];

    $layouts  = $options ['featured_product_content_layout'];

    if ( ! empty( $options['featured_product_content_select_category'] ) ) {

        $category_list                  =  (array) $options['featured_product_content_select_category'] ;

        $flat_commerce_category_content = '<div class="col col-4-of-12  col-push-1-of-12">
                                                <div class="row">';

        for ($i=0; $i < count( $category_list ); $i++) {
            $cat             = $category_list[$i];

            $cat_link        = get_term_link( (int)$cat, 'product_cat' );

            $term_values     = get_term_by( 'id', $cat, 'product_cat' );

            $title_attribute = $term_values->name;

            $thumbnail_id    = get_woocommerce_term_meta( $cat, 'thumbnail_id', true );
            $image           = wp_get_attachment_image_src( $thumbnail_id, 'flat-commerce-featured-product' );

            $flat_commerce_category_content .= '
            <div class="col col-1-of-'.$layouts.'">
                <div class="product-item product-hover">';
            if ( !empty( $image ) ) {
                $flat_commerce_category_content .= '<img src="'.esc_url( $image[0] ).'" alt="'.esc_attr( $title_attribute ).'" title="'.esc_attr( $title_attribute ).'" />';
            }
            else {
                $flat_commerce_first_image = wc_placeholder_img( 'flat-commerce-featured-product' );;

                if ( '' != $flat_commerce_first_image ) {
                    $flat_commerce_category_content .= $flat_commerce_first_image;
                }
            }

            $flat_commerce_category_content .= '
                <div class="mask">
                    <div class="v-center">
                        <div class="name-of-product">'.$title_attribute.'</div>';
                        if ( !$options['featured_product_content_url_option'] ) {
                            $flat_commerce_category_content .= '<a href="'.esc_url( $cat_link ).'" class="add-to-chart">'. esc_html__( 'View Details','flat-commerce' ) .'</a>';
                        }

            $flat_commerce_category_content .=
                    '</div>
                </div>  <!-- .mask -->';
            $flat_commerce_category_content .= '
                        </div>  <!-- .product-item -->
                    </div><!-- .col -->';
        }

        $flat_commerce_category_content .= '
            </div><!-- .row -->
        </div><!-- .col -->';

        return $flat_commerce_category_content;
    }

}
endif; // flat_commerce_category_content


if ( ! function_exists( 'flat_commerce_image_content' ) ) :
/**
 * This function to display featured posts content
 *
 * @get the data value from theme options
 * @displays on the index
 *
 * @useage Featured Image, Title and Excerpt of Post
 *
 * @uses set_transient
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_image_content( $options ) {
    $quantity       = $options [ 'featured_product_content_number' ];

    $more_link_text = $options['excerpt_more_text'];

    $layouts     = $options ['featured_product_content_layout'];

    $flat_commerce_image_content = '<div class="col col-4-of-12  col-push-1-of-12">
                                        <div class="row">';

    for ( $i = 1; $i <= $quantity; $i++ ) {
        if ( !empty ( $options[ 'featured_product_content_target_' . $i ] ) ) {
            $target = '_blank';
        } else {
            $target = '_self';
        }

        //Checking Link
        if ( !empty ( $options[ 'featured_product_content_link_' . $i ] ) ) {
            //support qTranslate plugin
            if ( function_exists( 'qtrans_convertURL' ) ) {
                $link = qtrans_convertURL(  $options[ 'featured_product_content_link_' . $i ] );
            }
            else {
                $link =  esc_url( $options[ 'featured_product_content_link_' . $i ] );
            }
        }
        else {
            $link = '#';
        }

        //Checking Title
        if ( !empty ( $options[ 'featured_product_content_title_'. $i ] ) ) {
            $title =$options[ 'featured_product_content_title_'. $i ];
        }
        else {
            $title = '';
        }

        $flat_commerce_image_content .= '
        <div class="col col-1-of-'.$layouts.'">
            <div class="product-item product-hover">';
            if ( !empty ( $options[ 'featured_product_content_image_' . $i ] ) ) {
                $flat_commerce_image_content .= '
                        <img src="'. esc_url( $options[ 'featured_product_content_image_' . $i ] ).'" alt="'.esc_attr( $title ).'" title="'.esc_attr( $title ).'"/>';
            }
            if ( $title != '' ) {
                $flat_commerce_image_content .= '
                <div class="mask">
                    <div class="v-center">
                            <div class="name-of-product">'.$title.'</div>';
            if ( $link != '' ) {
                $flat_commerce_image_content .=
                            '<a class="add-to-cart" href="'.esc_url( $link ).'" rel="bookmark" target="'.$target.'">'. esc_html__( 'View Details','flat-commerce' ) .'</a>';
                }
                    $flat_commerce_image_content .=
                            '</div>
                </div>  <!-- .mask -->';
            }
            $flat_commerce_image_content .= '
            </div>  <!-- .product-item -->
        </div><!-- .col -->';
    }
    $flat_commerce_image_content .= '
            </div><!-- .row -->
        </div><!-- .col -->';
    return $flat_commerce_image_content;
}
endif; //flat_commerce_image_content