<?php
/**
 * The template for displaying the Product Slider
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
    header( 'Status: 403 Forbidden' );
    header( 'HTTP/1.1 403 Forbidden' );
    exit();
}


if( !function_exists( 'flat_commerce_product_slider' ) ) :
/**
 * Add Product slider.
 *
 * @uses action hook flat_commerce_before_content.
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_product_slider() {
    global $post, $wp_query;

    //flat_commerce_flush_transients();
    // get data value from options
    $options          = flat_commerce_get_theme_options();
    $defaults         = flat_commerce_get_default_theme_options();

    $enableslider     = $options['product_slider_option'];
    $sliderselect     = $options['product_slider_type_select'];
    $banner_control   = $options['product_slider_exclusive_banner_control'];
    $exclusive_banner = $options['product_slider_exclusive_banner'];
    $exclusive_banner_url = $options['product_slider_exclusive_banner_url'];
    $banner_alt_text  = $options['product_slider_banner_alt_text'];

    // Get Page ID outside Loop
    $page_id = $wp_query->get_queried_object_id();

    // Front page displays in Reading Settings
    $page_on_front     = get_option('page_on_front') ;

    if ( $enableslider == 'entire-site' || ( ( $page_id == $page_on_front && $page_id > 0  ) && $enableslider == 'homepage' ) ) {
          if( ( ! $flat_commerce_product_slider = get_transient( 'flat_commerce_product_slider' ) ) ) {
            echo '<!-- refreshing cache of product slider -->';

            $flat_commerce_product_slider = '
                <section id="product-section">
                    <div class="container">
                        <div class="product-wrapper">
                            <div class="row">
                                <div class="col col-1-of-1">
                                    <header class="entry-header screen-reader-text">
                                        <h2 class="entry-title">' . esc_html__( 'Product Slider', 'flat-commerce' ) .
                                        '</h2>
                                    </header><!-- .entry-header -->';

                                            // Select Product Slider
                                            if ( $sliderselect == 'demo-product-slider' && function_exists( 'flat_commerce_product_demo_slider' ) ) {
                                                $flat_commerce_product_slider .=  flat_commerce_product_demo_slider();
                                            }
                                            elseif( $sliderselect == 'category-product-slider' && function_exists( 'flat_commerce_product_category_slider' ) ){
                                                $flat_commerce_product_slider .=  flat_commerce_product_category_slider( $options , $defaults );
                                            }

                                            // Exclusive banner options
                                            if( ! $banner_control  && 'disabled' != $enableslider ){
                                                $flat_commerce_product_slider .= '
                                                    <div class="exclusive-banner">';

                                                        $flat_commerce_product_slider .= '
                                                        <a href="'.esc_url( $exclusive_banner_url ).'"><img src="' . esc_url( $exclusive_banner ) . '" alt="' . esc_attr( $banner_alt_text ).'" title="' . esc_attr( $banner_alt_text ).'"/></a>
                                                    </div>';
                                            }

                            $flat_commerce_product_slider .='
                                </div><!-- .col -->
                            </div><!-- .row -->
                        </div><!-- .product-wrapper -->
                    </div><!-- .container -->
                </section><!-- #product-section -->';

            set_transient( 'flat_commerce_product_slider', $flat_commerce_product_slider, 86940 );
        }
        echo $flat_commerce_product_slider;
    }
}
endif;
add_action( 'flat_commerce_before_content', 'flat_commerce_product_slider', 50 );


if ( ! function_exists( 'flat_commerce_product_demo_slider' ) ) :
/**
 * This function to display product demo slider
 *
 * @since Flat Commerce Pro 1.0
 *
 */
function flat_commerce_product_demo_slider() {
    $flat_commerce_product_demo_slider ='
            <div id="tabs" class="tab-content">
                <ul class="ui-tabs-nav">
                    <li><a href="#tabs-1">'. esc_html__( 'Mens Wear','flat-commerce' ) .'</a></li>
                    <li><a href="#tabs-2">'. esc_html__( 'Accessories','flat-commerce' ) .'</a></li>
                    <li><a href="#tabs-3">'. esc_html__( 'Womens Wear','flat-commerce' ) .'</a></li>
                    <li><a href="#tabs-4">'. esc_html__( 'Watches','flat-commerce' ) .'</a></li>
                    <li><a href="#tabs-5">'. esc_html__( 'Sunglasses','flat-commerce' ) .'</a></li>
                </ul>
                <div id="tabs-1">
                    <div class="" id="mens">
                        <div class="tab-slider-wrapper">
                            <div class="responsive cycle-slideshow"
                                 data-cycle-swipe="true"
                                 
                                 data-cycle-speed="1000"
                                 data-cycle-loader="true"
                                 data-cycle-slides="> ul"
                                 data-cycle-prev="#prev1"
                                 data-cycle-next="#next1"
                                 >

                                <ul class="slides">
                                    <li class="col col-1-of-3 col-m-1-of-2">
                                        <a href="'.esc_url( home_url( '/' ) ).'">
                                            <img src="'.get_template_directory_uri().'/images/gallery/men1.jpg" alt="'.esc_attr__( 'men','flat-commerce' ) .'"/>
                                            <div class="product-item-wrapper">
                                                <div class="type-of-product">
                                                    '. esc_html__( 'Hiking and Adventure','flat-commerce' ) .'
                                                </div>
                                                <div class="total">
                                                    <a href="#">
                                                        '. esc_html__( '$170.00','flat-commerce' ) .'
                                                    </a>
                                                </div>
                                            </div>
                                        </a>
                                    </li>
                                    <li class="col col-1-of-3 col-m-1-of-2">
                                        <a href="'.esc_url( home_url( '/' ) ).'">
                                            <img src="'.get_template_directory_uri().'/images/gallery/men2.jpg" alt="'.esc_attr__( 'men','flat-commerce' ) .'"/>
                                            <div class="product-item-wrapper">
                                                <div class="type-of-product">
                                                    '. esc_html__( 'Party wear clothes','flat-commerce' ) .'
                                                </div>
                                                <div class="total">
                                                    <a href="#">
                                                        '. esc_html__( '$55.00','flat-commerce' ) .'
                                                    </a>
                                                </div>
                                            </div>
                                        </a>

                                    </li>
                                    <li class="col col-1-of-3 col-m-1-of-2">
                                        <a href="'.esc_url( home_url( '/' ) ).'">
                                            <img src="'.get_template_directory_uri().'/images/gallery/men3.jpg" alt="'.esc_attr__( 'men','flat-commerce' ) .'"/>
                                            <div class="product-item-wrapper">
                                                <div class="type-of-product">
                                                    '. esc_html__( 'Hiking and adventure','flat-commerce' ) .'
                                                </div>
                                                <div class="total">
                                                    <a href="#">
                                                        '. esc_html__( '$300.00','flat-commerce' ) .'
                                                    </a>
                                                </div>
                                            </div>
                                        </a>
                                    </li>

                                </ul><!-- .slides -->
                                <ul class="slides">
                                    <li class="col col-1-of-3 col-m-1-of-2">
                                        <a href="'.esc_url( home_url( '/' ) ).'">
                                            <img src="'.get_template_directory_uri().'/images/gallery/men1.jpg" alt="'.esc_attr__( 'men','flat-commerce' ) .'" />
                                            <div class="product-item-wrapper">
                                                <div class="type-of-product">
                                                    '. esc_html__( 'Stich Fashion collection','flat-commerce' ) .'
                                                </div>
                                                <div class="total">
                                                    <a href="#">
                                                        '. esc_html__( '$599.00','flat-commerce' ) .'
                                                    </a>
                                                </div>
                                            </div>
                                        </a>
                                    </li>
                                    <li class="col col-1-of-3 col-m-1-of-2">
                                        <a href="'.esc_url( home_url( '/' ) ).'">
                                            <img src="'.get_template_directory_uri().'/images/gallery/men2.jpg" alt="'.esc_attr__( 'men','flat-commerce' ) .'" />
                                            <div class="product-item-wrapper">
                                                <div class="type-of-product">
                                                    '. esc_html__( 'Stich Fashion collection','flat-commerce' ) .'
                                                </div>
                                                <div class="total">
                                                    <a href="#">
                                                        '. esc_html__( '$290.00','flat-commerce' ) .'
                                                    </a>
                                                </div>
                                            </div>
                                        </a>

                                    </li>
                                    <li class="col col-1-of-3 col-m-1-of-2">
                                        <a href="'.esc_url( home_url( '/' ) ).'">
                                            <img src="'.get_template_directory_uri().'/images/gallery/men3.jpg" alt="'.esc_attr__( 'men','flat-commerce' ) .'"/>
                                            <div class="product-item-wrapper">
                                                <div class="type-of-product">
                                                    '. esc_html__( 'Stich Fashion collection','flat-commerce' ) .'
                                                </div>
                                                <div class="total">
                                                    <a href="#">
                                                        '. esc_html__( '$290.00','flat-commerce' ) .'
                                                    </a>
                                                </div>
                                            </div>
                                        </a>
                                    </li>
                                </ul><!-- .slides -->
                            </div><!-- cycle-slideshow -->
                            <span href="#" class="cycle-previous" id="cycle-prev"><span class="genericon genericon-previous"></span></span>
                            <span href="#" class="cycle-next" id="cycle-next"><span class="genericon genericon-next"></span></span>
                        </div><!-- .tab-slider-wrapper -->
                    </div><!-- .#mens -->
                </div><!-- #tabs-1 -->
                <div id="tabs-2">
                    <p>'. esc_html__( 'This is Accessories','flat-commerce' ) .'</p>
                </div><!-- #tabs-2 -->

                <div id="tabs-3">
                    <p>'. esc_html__( 'This is womens wear','flat-commerce' ) .'</p>
                </div><!-- #tabs-3 -->
                <div id="tabs-4">
                    <p>'. esc_html__( 'This is watches','flat-commerce' ) .'</p>
                </div><!-- #tabs-4 -->
                <div id="tabs-5">
                    <p>'. esc_html__( 'This is sunglasses','flat-commerce' ) .'</p>
                </div><!-- #tabs-5 -->
            </div><!-- #tabs -->';
    return $flat_commerce_product_demo_slider;
}
endif; // flat_commerce_product_demo_slider

if ( ! function_exists( 'flat_commerce_product_category_slider' ) ) :
/**
 * This function to display Product category slider
 *
 * @get the data value from customizer options
 *
 * @since Flat Commerce Pro 1.0
 *
 */
function flat_commerce_product_category_slider( $options, $defaults ) {
    global $post;

    $product_slider_no_of_tabs              = $options['product_slider_no_of_tabs'];

    $flat_commerce_product_category_slider  = '';

    if( !empty( $product_slider_no_of_tabs ) && ( $product_slider_no_of_tabs > 0 ) ){
        $flat_commerce_product_category_slider ='
            <div id="tabs" class="tab-content">
                <ul class="ui-tabs-nav">';
        for( $i = 1; $i <= $product_slider_no_of_tabs; $i++ ){
            if( isset( $options['product_slider_category_'.$i ] ) && $options['product_slider_category_'.$i ] > 0 ){
                $flat_commerce_product_category_slider .='
                    <li><a href="#tabs-' . intval( $options['product_slider_category_' . $i ] ) . '-' . $i . '" >' .get_product_category_by_id( intval( $options['product_slider_category_' . $i ] ) ) . '</a></li>';
            }
        }
        $flat_commerce_product_category_slider .='
                </ul>';

        for( $i = 1; $i <= $product_slider_no_of_tabs; $i++ ) {
            if( !empty( $options['product_slider_category_' . $i ] ) ){
                $flat_commerce_product_category_slider .='
                    <div id="tabs-' . intval( $options['product_slider_category_' . $i ] ) . '-' . $i . '">
                        <div class="" id="mens">
                            <div class="tab-slider-wrapper">
                                <div class="cycle-slideshow"
                                    data-cycle-swipe="true"
                                    data-cycle-loop = "1"
                                    data-cycle-fx="' . esc_html( $options['product_slide_transition_effect'] ) . '"
                                    data-cycle-speed="' . absint( $options['product_slide_transition_length'] ) * 1000 . '"
                                    data-cycle-timeout="' . absint( $options['product_slide_transition_delay'] ) * 1000 . '"
                                    data-cycle-loader="true"
                                    data-cycle-slides="> ul"
                                    data-cycle-prev="#cycle-prev'.$i.'"
                                    data-cycle-next="#cycle-next'.$i.'"
                                    >
                                    <ul class="slides">';


                            $li_count = 1;

                            $posts_per_category = isset( $options['product_slider_no_of_products_for_category_' . $i ] ) ? $options['product_slider_no_of_products_for_category_' . $i ] : $defaults['product_slider_no_of_products_for_category'];

                            $layout_options     = isset( $options['product_slider_layout_option_' . $i ] ) ? $options['product_slider_layout_option_' . $i ] : $defaults['product_slider_layout_option'];

                            $category_args      = array(
                                'post_type'     => 'product',
                                'post_status'   => 'publish',
                                'posts_per_page'=> $posts_per_category,
                                'tax_query'     => array(
                                    array(
                                    'taxonomy'      => 'product_cat',
                                    'terms'         => $options['product_slider_category_' . $i ],
                                    )
                                ),
                            );
                            $category_query     = new WP_Query( $category_args );

                            while(  $category_query -> have_posts() ){
                                    $category_query -> the_post();

                                    $slider_product = wc_get_product();

                                    $flat_commerce_product_category_slider .= '
                                        <li class="col col-1-of-' . $layout_options . ' col-m-1-of-2" >
                                            <a href="' . esc_url( get_permalink() ) . '">';

                                                if( has_post_thumbnail() ){
                                                    $flat_commerce_product_category_slider .= woocommerce_get_product_thumbnail( 'flat-commerce-product-slider');
                                                }
                                                else{
                                                    $flat_commerce_product_category_slider .= wc_placeholder_img( 'flat-commerce-product-slider' );
                                                }

                                    $flat_commerce_product_category_slider .= '
                                                </a><div class="product-item-wrapper">
                                                    <div class="type-of-product"><a href="' . esc_url( get_permalink() ) . '">' . $slider_product -> get_title() . '</a></div>
                                                    <div class="total">
                                                       ' . wc_price( $slider_product -> get_price() ) . '

                                                    </div>
                                                </div>

                                        </li>';

                                if ( 0 == ( $li_count % $layout_options ) && ( $posts_per_category > $layout_options ) ) { // insert new ul element if posts_per_page is greater than layout option
                                    $flat_commerce_product_category_slider .= '
                                    </ul><!-- .slides -->
                                    <ul class="slides">';
                                }

                            $li_count++;
                            }

                            wp_reset_query();
                            $flat_commerce_product_category_slider .= '
                                    </ul>';
                            $flat_commerce_product_category_slider.= '
                                </div><!-- cycle-slideshow -->';

                                if(  $posts_per_category > $layout_options ){
                                    $flat_commerce_product_category_slider .= '
                                        <span href="#" class="cycle-previous" id="cycle-prev'.$i.'"><span class="genericon genericon-previous"></span></span>
                                        <span href="#" class="cycle-next" id="cycle-next'.$i.'"><span class="genericon genericon-next"></span></span>';
                                }

                            $flat_commerce_product_category_slider.='
                            </div><!-- .tab-slider-wrapper -->
                        </div><!-- .tab-pane -->
                    </div><!-- #tabs-' . $options['product_slider_category_' . $i ] . '-' . $i . '-->';
            }
        }
        $flat_commerce_product_category_slider .='
            </div><!-- #tabs --></ul>';
    }
    return  $flat_commerce_product_category_slider;
}
endif; // flat_commerce_product_category_slider

//Function to get Woocommerce category name using category id
function get_product_category_by_id( $category_id ) {

    $term = get_term_by( 'id', $category_id, 'product_cat', 'ARRAY_A' );
    return $term['name'];

}
