<?php
/**
 * The template for additional social media widget
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}


/**
 * Adds additional social media widget.
 */
class Flatcommerce_additional_social_media_widget extends WP_Widget {

	/**
	 * Register widget with WordPress.
	 */
	function __construct() {
		parent::__construct(
			'additional_social_media', // Base ID
			__( 'TP: Additional Social Media', 'flat-commerce' ), // Name
			array( 'description' => __( 'An widget to add additional social medias in sidebar.', 'flat-commerce' ), ) // Args
		);
	}

	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
	public function widget( $args, $instance ) {
		extract( $args , EXTR_SKIP );

		$title 				= apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this ->id_base );

		$social_icons_lists = flat_commerce_get_social_icons_list(); // get social media icons

		echo $args['before_widget'];

		if ( ! empty( $title ) ) {
					echo  $args['before_title'] . '<span>' . $title . '</span>' . $args['after_title'];
		}

		echo '<div class="social-icon-wrapper">';

		foreach ( $social_icons_lists as $social_icons_list ) {

			if( isset( $instance[ $social_icons_list['genericon_class'] ] ) && '' != $instance[ $social_icons_list['genericon_class'] ] ){

				$output = '';
				$genericon_label  = $social_icons_list['label'];
				$genericon_class  = $social_icons_list['genericon_class'];
				$social_media_url = $instance[ $social_icons_list['genericon_class'] ];


				if( 'mail' == $genericon_class ){
					echo '<a href="mailto:' . antispambot( sanitize_email ( $social_media_url ) ) . '" target="_blank">
						<span class="genericon genericon-' . sanitize_key( $genericon_class ) . '" ></span>
						<span class="screen-reader-text">' . __( 'Email', 'flat-commerce') . '</span></a>';
				}

				elseif( 'skype' == $genericon_class ){
					echo '<a href="skype:'. esc_attr( $social_media_url ) . '" target="_blank">
						<span class="genericon genericon-' . sanitize_key( $genericon_class ) . '"></span>
						<span class="screen-reader-text">' . __( 'Skype', 'flat-commerce') . '</span></a>';
				}

				elseif( 'phone' == $genericon_class || 'handset' == $genericon_class  ){
					echo '<a href="tel:' . preg_replace( '/\s+/', '', esc_attr( $social_media_url ) ) . '" target="_blank">
						<span class="genericon genericon-' . sanitize_key( $genericon_class ) . '"></span>
						<span class="screen-reader-text">' . esc_attr( $genericon_label ) . '</span></a>';
				}

				else{
					echo '<a href="' . esc_url( $social_media_url ) . '" target="_blank">
						<span class="genericon genericon-' . sanitize_key( $genericon_class ) . '"></span>
						<span class="screen-reader-text">' . esc_attr( $genericon_label ) . '</span></a>';
					}
			}

		}
		echo '</div>';

		echo $args['after_widget'];
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 */
	public function form( $instance ) {
		$social_icons_lists = flat_commerce_get_social_icons_list();

		$title = isset( $instance['title'] ) ? $instance['title'] : '';

		//default values for social media urls
		foreach ( $social_icons_lists as $social_icons_list ) {
			$defaults[ $social_icons_list['genericon_class'] ] = '';
		}

		//merge instance value with default values
      $instance = wp_parse_args( (array) $instance, $defaults );

		?>
		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php _e( 'Title:', 'flat-commerce' ); ?></label>
			<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>"/>
		</p>

		<?php foreach( $social_icons_lists as $social_icons_list ){

			$social_media_url[ $social_icons_list['genericon_class'] ]	=  $instance[ $social_icons_list['genericon_class'] ];


		?>
		<p>
			<label for="<?php echo esc_attr( ( $social_icons_list['genericon_class'] ) ); ?>"><?php echo esc_html( $social_icons_list['label'] ); ?></label>
			<?php
					if( 'skype' == $social_icons_list['genericon_class'] ) { ?>
						<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'skype' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'skype' ) ); ?>" type="text" value="<?php echo esc_attr( $social_media_url['skype'] ); ?>"/>
			<?php 	}

		 			elseif( 'mail' == $social_icons_list['genericon_class'] ) { ?>

						<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'mail' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'mail' ) ); ?>" type="text" value="<?php echo sanitize_email( $social_media_url['mail'] ); ?>"/>
			<?php 	}

					elseif( 'handset' == $social_icons_list['genericon_class'] ) { ?>
						<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'handset' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'handset' ) ); ?>" type="text" value="<?php echo sanitize_text_field( $social_media_url['handset'] ) ; ?>"/>
			<?php 	}
					elseif( 'phone' == $social_icons_list['genericon_class'] ) { ?>
						<input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'phone' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'phone' ) ); ?>" type="text" value="<?php echo sanitize_text_field( $social_media_url['phone'] ) ; ?>"/>
			<?php 	}
					else { ?>
						<input class="widefat" id="<?php echo esc_attr( ( $social_icons_list['genericon_class'] ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( ( $social_icons_list['genericon_class'] ) ) ); ?>" type="text" value="<?php echo esc_url( $social_media_url[ $social_icons_list['genericon_class'] ] ) ; ?>"/>
			<?php	} ?>
			</p>

			<?php
		}
	}

	/**
	 * Sanitize widget form values as they are saved.
	 *
	 * @see WP_Widget::update()
	 *
	 * @param array $new_instance Values just sent to be saved.
	 * @param array $old_instance Previously saved values from database.
	 *
	 * @return array Updated safe values to be saved.
	 */
	public function update( $new_instance, $old_instance ) {
		$instance           = $old_instance;

		$instance['title']  = ( ! empty( $new_instance['title'] ) ) ? strip_tags( stripslashes ( $new_instance['title'] ) ) : '';

		$social_icons_lists = flat_commerce_get_social_icons_list(); // load default social medias icons lists

		foreach( $social_icons_lists as $social_icons_list ){

			switch ( $social_icons_list['genericon_class']) {
				case 'skype' :
					$instance['skype']  = esc_attr(  $new_instance['skype']);
					break;

				case 'mail' :
					$instance['mail']  	= sanitize_email( $new_instance['mail'] );
					break;

				case 'handset' :
					$instance['handset']  	= sanitize_text_field(  $new_instance['handset']);
					break;

				case 'phone' :
					$instance['phone']  	= sanitize_text_field(  $new_instance['phone'] );
					break;

				default:
					$instance[ $social_icons_list['genericon_class'] ]  = esc_url(  $new_instance[ $social_icons_list['genericon_class'] ]);
			}
		}
		return ( $instance );
	}

} // class Flatcommerce_additional_social_media_widget
