<?php
/**
 * The template for adding Custom Sidebars and Widgets
 *
 * @package Theme Palace
 * @subpackage Flat Commerce Pro
 * @since Flat Commerce Pro 1.0
 */

if ( ! defined( 'FLAT_COMMERCE_THEME_VERSION' ) ) {
	header( 'Status: 403 Forbidden' );
	header( 'HTTP/1.1 403 Forbidden' );
	exit();
}
/**
 * Register widgetized area and update sidebar with default widgets
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_widgets_init() {
	//Primary Sidebar
	register_sidebar( array(
		'name'          => __( 'Primary Sidebar', 'flat-commerce' ),
		'id'            => 'primary-sidebar',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
		'description'	=> __( 'This is the primary sidebar if you are using a two column site layout option.', 'flat-commerce' ),
	) );

	register_sidebar( array(
		'name'          => __( 'Front Page Widget', 'flat-commerce' ),
		'id'            => 'front-page-widget',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
		'description'	=> __( 'Widgets dropped here will be displayed only on front page section. Recommended number of widgets :4.', 'flat-commerce' ),
	) );

	$footer_sidebar_number = 4; //Number of footer sidebars

	for( $i=1; $i <= $footer_sidebar_number; $i++ ) {
		register_sidebar( array(
			'name'          => sprintf( __( 'Footer Area %d', 'flat-commerce' ), $i ),
			'id'            => sprintf( 'footer-%d', $i ),
			'before_widget' => '<aside class="widget"><div class="widget-wrap">',
			'after_widget'  => '</div><!-- .widget-wrap --></aside><!-- #widget-default-search -->',
			'before_title'  => '<div class="entry-header"><h3 class="widget-title">',
			'after_title'   => '</h3></div>',
			'description'	=> sprintf( __( 'Footer %d widget area.', 'flat-commerce' ), $i ),
		) );
	}

	//Header Right
	register_sidebar( array(
		'name'          => __( 'Header Right', 'flat-commerce' ),
		'id'            => 'header-right',
		'before_widget' => '<section id="%1$s" class="widget %2$s"><div class="widget-wrap">',
		'after_widget'  => '</div><!-- .widget-wrap --></section><!-- #widget-default-search -->',
		'before_title'  => '<h4 class="widget-title">',
		'after_title'   => '</h4>',
		'description'	=> __( 'This is the header right widget area. It typically appears on the right of the site title or logo. This widget area is not equipped to display any widget, and works best with a custom menu assigned as header right menu, a search form, social icons widget or possibly a text widget.', 'flat-commerce' ),
	) );


	// Registering 404 Error Page Content
	register_sidebar( array(
		'name'					=> __( '404 Page Not Found Content', 'flat-commerce' ),
		'id' 					=> 'sidebar-notfound',
		'description'			=> __( 'Replaces the default 404 Page Not Found Content', 'flat-commerce' ),
		'before_widget'			=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget'			=> '</aside>',
		'before_title'			=> '<h2 class="widget-title">',
		'after_title'			=> '</h2>',
	) );

	if ( class_exists( 'WooCommerce' ) ) {
		//Optional Primary Sidebar for Shop
		register_sidebar( array(
			'name' 				=> __( 'WooCommerce Primary Sidebar', 'flat-commerce' ),
			'id' 				=> 'sidebar-optional-woocommmerce',
			'description'		=> __( 'This is Optional Primary Sidebar for WooCommerce', 'flat-commerce' ),
			'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
			'after_widget' 		=> "</aside>",
			'before_title' 		=> '<h3 class="widget-title">',
			'after_title' 		=> '</h3>'
		) );
	}

	//Optional Sidebar for Hompeage instead of main sidebar
	register_sidebar( array(
		'name' 				=> __( 'Optional Homepage Sidebar', 'flat-commerce' ),
		'id' 				=> 'sidebar-optional-homepage',
		'description'		=> __( 'This is Optional Sidebar for Homepage', 'flat-commerce' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar for Archive instead of main sidebar
	register_sidebar( array(
		'name' 				=> __( 'Optional Archive Sidebar', 'flat-commerce' ),
		'id' 				=> 'sidebar-optional-archive',
		'description'		=> __( 'This is Optional Sidebar for Archive', 'flat-commerce' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar for Page instead of main sidebar
	register_sidebar( array(
		'name' 				=> __( 'Optional Page Sidebar', 'flat-commerce' ),
		'id' 				=> 'sidebar-optional-page',
		'description'		=> __( 'This is Optional Sidebar for Page', 'flat-commerce' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar for Post instead of main sidebar
	register_sidebar( array(
		'name' 				=> __( 'Optional Post Sidebar', 'flat-commerce' ),
		'id' 				=> 'sidebar-optional-post',
		'description'		=> __( 'This is Optional Sidebar for Post', 'flat-commerce' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar one for page and post
	register_sidebar( array(
		'name' 				=> __( 'Optional Sidebar One', 'flat-commerce' ),
		'id' 				=> 'sidebar-optional-one',
		'description'		=> __( 'This is Optional Sidebar One', 'flat-commerce' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar two for page and post
	register_sidebar( array(
		'name' 				=> __( 'Optional Sidebar Two', 'flat-commerce' ),
		'id' 				=> 'sidebar-optional-two',
		'description'		=> __( 'This is Optional Sidebar Two', 'flat-commerce' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Optional Sidebar Three for page and post
	register_sidebar( array(
		'name' 				=> __( 'Optional Sidebar Three', 'flat-commerce' ),
		'id' 				=> 'sidebar-optional-three',
		'description'		=> __( 'This is Optional Sidebar Three', 'flat-commerce' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//advertisement widget for page and post
	register_sidebar( array(
		'name' 				=> __( 'Advertisement widget', 'flat-commerce' ),
		'id' 				=> 'sidebar-advertisement',
		'description'		=> __( 'This is Advertisement widget', 'flat-commerce' ),
		'before_widget' 	=> '<aside id="%1$s" class="widget %2$s">',
		'after_widget' 		=> "</aside>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );

	//Contact Sidebar for contact template
	register_sidebar( array(
		'name' 				=> __( 'Contact Sidebar', 'flat-commerce' ),
		'id' 				=> 'sidebar-contact',
		'description'		=> __( 'This is Contact Sidebar', 'flat-commerce' ),
		'before_widget' 	=> '<div id="%1$s" class="col col-1-of-'.flat_commerce_sidebar_widgets_count( 'sidebar-contact' ).'">',
		'after_widget' 		=> "</div>",
		'before_title' 		=> '<h3 class="widget-title">',
		'after_title' 		=> '</h3>'
	) );
}
add_action( 'widgets_init', 'flat_commerce_widgets_init' );

/**
* Load Social Icons Widget
*/
require get_template_directory() . '/inc/widgets-includes/social-icons-widget.php';

/**
* Load Featured Page Widget
*/
require get_template_directory() . '/inc/widgets-includes/get-page-widget.php';

/**
* Load Featured Post Widget
*/
require get_template_directory() . '/inc/widgets-includes/featured-post-widget.php';

/**
* Load Adspace Widget
*/
require get_template_directory() . '/inc/widgets-includes/adspace-widget.php';

/**
* Load Image Widget
*/
require get_template_directory() . '/inc/widgets-includes/image-widget.php';

/**
* Load Contact Fields Widget
*/
require get_template_directory() . '/inc/widgets-includes/contact-fields-widget.php';

require get_template_directory() . '/inc/widgets-includes/additional-social-media-widget.php';

/**
 * Register Widgets
 *
 * @since Flat Commerce Pro 1.0
 */
function flat_commerce_register_widgets() {
    register_widget( 'Flatcommerce_social_icons_widget' );

	register_widget( 'Flatcommerce_get_page_widget' );

	register_widget( 'Flatcommerce_featured_post_widget' );

	register_widget( 'Flatcommerce_adspace_widget' );

	register_widget( 'Flatcommerce_image_widget' );

	register_widget( 'Flat_Commerce_Widget_Contact_Fields' );

	register_widget( 'Flatcommerce_additional_social_media_widget' );
}
add_action( 'widgets_init', 'flat_commerce_register_widgets' );